# coding=utf-8
# *** WARNING: this file was generated by the Pulumi Terraform Bridge (tfgen) Tool. ***
# *** Do not edit by hand unless you're certain you know what you are doing! ***

import copy
import warnings
import sys
import pulumi
import pulumi.runtime
from typing import Any, Mapping, Optional, Sequence, Union, overload
if sys.version_info >= (3, 11):
    from typing import NotRequired, TypedDict, TypeAlias
else:
    from typing_extensions import NotRequired, TypedDict, TypeAlias
from .. import _utilities
from . import outputs

__all__ = [
    'DiAlarmRuleNotificationSettings',
    'DiAlarmRuleNotificationSettingsNotificationChannel',
    'DiAlarmRuleNotificationSettingsNotificationReceiver',
    'DiAlarmRuleTriggerCondition',
    'DiJobDestinationDataSourceSetting',
    'DiJobJobSettings',
    'DiJobJobSettingsColumnDataTypeSetting',
    'DiJobJobSettingsCycleScheduleSettings',
    'DiJobJobSettingsDdlHandlingSetting',
    'DiJobJobSettingsRuntimeSetting',
    'DiJobResourceSettings',
    'DiJobResourceSettingsOfflineResourceSettings',
    'DiJobResourceSettingsRealtimeResourceSettings',
    'DiJobResourceSettingsScheduleResourceSettings',
    'DiJobSourceDataSourceSetting',
    'DiJobSourceDataSourceSettingDataSourceProperties',
    'DiJobTableMapping',
    'DiJobTableMappingSourceObjectSelectionRule',
    'DiJobTableMappingTransformationRule',
    'DiJobTransformationRule',
    'ProjectMemberRole',
    'GetFoldersFolderResult',
]

@pulumi.output_type
class DiAlarmRuleNotificationSettings(dict):
    @staticmethod
    def __key_warning(key: str):
        suggest = None
        if key == "inhibitionInterval":
            suggest = "inhibition_interval"
        elif key == "notificationChannels":
            suggest = "notification_channels"
        elif key == "notificationReceivers":
            suggest = "notification_receivers"

        if suggest:
            pulumi.log.warn(f"Key '{key}' not found in DiAlarmRuleNotificationSettings. Access the value via the '{suggest}' property getter instead.")

    def __getitem__(self, key: str) -> Any:
        DiAlarmRuleNotificationSettings.__key_warning(key)
        return super().__getitem__(key)

    def get(self, key: str, default = None) -> Any:
        DiAlarmRuleNotificationSettings.__key_warning(key)
        return super().get(key, default)

    def __init__(__self__, *,
                 inhibition_interval: Optional[int] = None,
                 notification_channels: Optional[Sequence['outputs.DiAlarmRuleNotificationSettingsNotificationChannel']] = None,
                 notification_receivers: Optional[Sequence['outputs.DiAlarmRuleNotificationSettingsNotificationReceiver']] = None):
        """
        :param int inhibition_interval: Alarm suppression interval, in minutes
        :param Sequence['DiAlarmRuleNotificationSettingsNotificationChannelArgs'] notification_channels: Alarm notification Channel See `notification_channels` below.
        :param Sequence['DiAlarmRuleNotificationSettingsNotificationReceiverArgs'] notification_receivers: List of alert notification recipients See `notification_receivers` below.
        """
        if inhibition_interval is not None:
            pulumi.set(__self__, "inhibition_interval", inhibition_interval)
        if notification_channels is not None:
            pulumi.set(__self__, "notification_channels", notification_channels)
        if notification_receivers is not None:
            pulumi.set(__self__, "notification_receivers", notification_receivers)

    @property
    @pulumi.getter(name="inhibitionInterval")
    def inhibition_interval(self) -> Optional[int]:
        """
        Alarm suppression interval, in minutes
        """
        return pulumi.get(self, "inhibition_interval")

    @property
    @pulumi.getter(name="notificationChannels")
    def notification_channels(self) -> Optional[Sequence['outputs.DiAlarmRuleNotificationSettingsNotificationChannel']]:
        """
        Alarm notification Channel See `notification_channels` below.
        """
        return pulumi.get(self, "notification_channels")

    @property
    @pulumi.getter(name="notificationReceivers")
    def notification_receivers(self) -> Optional[Sequence['outputs.DiAlarmRuleNotificationSettingsNotificationReceiver']]:
        """
        List of alert notification recipients See `notification_receivers` below.
        """
        return pulumi.get(self, "notification_receivers")


@pulumi.output_type
class DiAlarmRuleNotificationSettingsNotificationChannel(dict):
    def __init__(__self__, *,
                 channels: Optional[Sequence[str]] = None,
                 severity: Optional[str] = None):
        """
        :param Sequence[str] channels: Channel, optional enumeration value:
               
               Mail (Mail)
               
               Phone (Phone)
               
               Sms (Sms)
               
               Ding (DingTalk)
        """
        if channels is not None:
            pulumi.set(__self__, "channels", channels)
        if severity is not None:
            pulumi.set(__self__, "severity", severity)

    @property
    @pulumi.getter
    def channels(self) -> Optional[Sequence[str]]:
        """
        Channel, optional enumeration value:

        Mail (Mail)

        Phone (Phone)

        Sms (Sms)

        Ding (DingTalk)
        """
        return pulumi.get(self, "channels")

    @property
    @pulumi.getter
    def severity(self) -> Optional[str]:
        return pulumi.get(self, "severity")


@pulumi.output_type
class DiAlarmRuleNotificationSettingsNotificationReceiver(dict):
    @staticmethod
    def __key_warning(key: str):
        suggest = None
        if key == "receiverType":
            suggest = "receiver_type"
        elif key == "receiverValues":
            suggest = "receiver_values"

        if suggest:
            pulumi.log.warn(f"Key '{key}' not found in DiAlarmRuleNotificationSettingsNotificationReceiver. Access the value via the '{suggest}' property getter instead.")

    def __getitem__(self, key: str) -> Any:
        DiAlarmRuleNotificationSettingsNotificationReceiver.__key_warning(key)
        return super().__getitem__(key)

    def get(self, key: str, default = None) -> Any:
        DiAlarmRuleNotificationSettingsNotificationReceiver.__key_warning(key)
        return super().get(key, default)

    def __init__(__self__, *,
                 receiver_type: Optional[str] = None,
                 receiver_values: Optional[Sequence[str]] = None):
        """
        :param str receiver_type: The type of the receiver. Valid values: AliyunUid/DingToken/FeishuToken/WebHookUrl.
        :param Sequence[str] receiver_values: Receiver Value List
        """
        if receiver_type is not None:
            pulumi.set(__self__, "receiver_type", receiver_type)
        if receiver_values is not None:
            pulumi.set(__self__, "receiver_values", receiver_values)

    @property
    @pulumi.getter(name="receiverType")
    def receiver_type(self) -> Optional[str]:
        """
        The type of the receiver. Valid values: AliyunUid/DingToken/FeishuToken/WebHookUrl.
        """
        return pulumi.get(self, "receiver_type")

    @property
    @pulumi.getter(name="receiverValues")
    def receiver_values(self) -> Optional[Sequence[str]]:
        """
        Receiver Value List
        """
        return pulumi.get(self, "receiver_values")


@pulumi.output_type
class DiAlarmRuleTriggerCondition(dict):
    @staticmethod
    def __key_warning(key: str):
        suggest = None
        if key == "ddlReportTags":
            suggest = "ddl_report_tags"

        if suggest:
            pulumi.log.warn(f"Key '{key}' not found in DiAlarmRuleTriggerCondition. Access the value via the '{suggest}' property getter instead.")

    def __getitem__(self, key: str) -> Any:
        DiAlarmRuleTriggerCondition.__key_warning(key)
        return super().__getitem__(key)

    def get(self, key: str, default = None) -> Any:
        DiAlarmRuleTriggerCondition.__key_warning(key)
        return super().get(key, default)

    def __init__(__self__, *,
                 ddl_report_tags: Optional[Sequence[str]] = None,
                 duration: Optional[int] = None,
                 severity: Optional[str] = None,
                 threshold: Optional[int] = None):
        """
        :param Sequence[str] ddl_report_tags: It takes effect only when the DDL notification is issued. The list of effective DDLs is required.
        :param int duration: Alarm calculation time interval, unit minute
        :param str severity: Severity, optional enumeration value:
               
               Warning
               
               Critical
        :param int threshold: Alarm threshold.
               
               Task status alarm: no need to fill in the threshold.
               
               failover alarm: The threshold is the number of failover alarms.
               
               Task Delay Alarm: The threshold is the delay duration, in seconds.
        """
        if ddl_report_tags is not None:
            pulumi.set(__self__, "ddl_report_tags", ddl_report_tags)
        if duration is not None:
            pulumi.set(__self__, "duration", duration)
        if severity is not None:
            pulumi.set(__self__, "severity", severity)
        if threshold is not None:
            pulumi.set(__self__, "threshold", threshold)

    @property
    @pulumi.getter(name="ddlReportTags")
    def ddl_report_tags(self) -> Optional[Sequence[str]]:
        """
        It takes effect only when the DDL notification is issued. The list of effective DDLs is required.
        """
        return pulumi.get(self, "ddl_report_tags")

    @property
    @pulumi.getter
    def duration(self) -> Optional[int]:
        """
        Alarm calculation time interval, unit minute
        """
        return pulumi.get(self, "duration")

    @property
    @pulumi.getter
    def severity(self) -> Optional[str]:
        """
        Severity, optional enumeration value:

        Warning

        Critical
        """
        return pulumi.get(self, "severity")

    @property
    @pulumi.getter
    def threshold(self) -> Optional[int]:
        """
        Alarm threshold.

        Task status alarm: no need to fill in the threshold.

        failover alarm: The threshold is the number of failover alarms.

        Task Delay Alarm: The threshold is the delay duration, in seconds.
        """
        return pulumi.get(self, "threshold")


@pulumi.output_type
class DiJobDestinationDataSourceSetting(dict):
    @staticmethod
    def __key_warning(key: str):
        suggest = None
        if key == "dataSourceName":
            suggest = "data_source_name"

        if suggest:
            pulumi.log.warn(f"Key '{key}' not found in DiJobDestinationDataSourceSetting. Access the value via the '{suggest}' property getter instead.")

    def __getitem__(self, key: str) -> Any:
        DiJobDestinationDataSourceSetting.__key_warning(key)
        return super().__getitem__(key)

    def get(self, key: str, default = None) -> Any:
        DiJobDestinationDataSourceSetting.__key_warning(key)
        return super().get(key, default)

    def __init__(__self__, *,
                 data_source_name: Optional[str] = None):
        """
        :param str data_source_name: Destination data source name
        """
        if data_source_name is not None:
            pulumi.set(__self__, "data_source_name", data_source_name)

    @property
    @pulumi.getter(name="dataSourceName")
    def data_source_name(self) -> Optional[str]:
        """
        Destination data source name
        """
        return pulumi.get(self, "data_source_name")


@pulumi.output_type
class DiJobJobSettings(dict):
    @staticmethod
    def __key_warning(key: str):
        suggest = None
        if key == "channelSettings":
            suggest = "channel_settings"
        elif key == "columnDataTypeSettings":
            suggest = "column_data_type_settings"
        elif key == "cycleScheduleSettings":
            suggest = "cycle_schedule_settings"
        elif key == "ddlHandlingSettings":
            suggest = "ddl_handling_settings"
        elif key == "runtimeSettings":
            suggest = "runtime_settings"

        if suggest:
            pulumi.log.warn(f"Key '{key}' not found in DiJobJobSettings. Access the value via the '{suggest}' property getter instead.")

    def __getitem__(self, key: str) -> Any:
        DiJobJobSettings.__key_warning(key)
        return super().__getitem__(key)

    def get(self, key: str, default = None) -> Any:
        DiJobJobSettings.__key_warning(key)
        return super().get(key, default)

    def __init__(__self__, *,
                 channel_settings: Optional[str] = None,
                 column_data_type_settings: Optional[Sequence['outputs.DiJobJobSettingsColumnDataTypeSetting']] = None,
                 cycle_schedule_settings: Optional['outputs.DiJobJobSettingsCycleScheduleSettings'] = None,
                 ddl_handling_settings: Optional[Sequence['outputs.DiJobJobSettingsDdlHandlingSetting']] = None,
                 runtime_settings: Optional[Sequence['outputs.DiJobJobSettingsRuntimeSetting']] = None):
        """
        :param str channel_settings: Channel-related task settings, in the form of a Json String.
               
               For example,
               {"structInfo":"MANAGED","storageType":"TEXTFILE","writeMode":"APPEND","partitionColumns":[{"columnName":"pt","columnType":"STRING","comment":""}],"fieldDelimiter":""}
        :param Sequence['DiJobJobSettingsColumnDataTypeSettingArgs'] column_data_type_settings: Column type mapping of the synchronization task See `column_data_type_settings` below.
        :param 'DiJobJobSettingsCycleScheduleSettingsArgs' cycle_schedule_settings: Periodic scheduling settings See `cycle_schedule_settings` below.
        :param Sequence['DiJobJobSettingsDdlHandlingSettingArgs'] ddl_handling_settings: List of DDL processing settings for synchronization tasks See `ddl_handling_settings` below.
        :param Sequence['DiJobJobSettingsRuntimeSettingArgs'] runtime_settings: Run-time setting parameter list See `runtime_settings` below.
        """
        if channel_settings is not None:
            pulumi.set(__self__, "channel_settings", channel_settings)
        if column_data_type_settings is not None:
            pulumi.set(__self__, "column_data_type_settings", column_data_type_settings)
        if cycle_schedule_settings is not None:
            pulumi.set(__self__, "cycle_schedule_settings", cycle_schedule_settings)
        if ddl_handling_settings is not None:
            pulumi.set(__self__, "ddl_handling_settings", ddl_handling_settings)
        if runtime_settings is not None:
            pulumi.set(__self__, "runtime_settings", runtime_settings)

    @property
    @pulumi.getter(name="channelSettings")
    def channel_settings(self) -> Optional[str]:
        """
        Channel-related task settings, in the form of a Json String.

        For example,
        {"structInfo":"MANAGED","storageType":"TEXTFILE","writeMode":"APPEND","partitionColumns":[{"columnName":"pt","columnType":"STRING","comment":""}],"fieldDelimiter":""}
        """
        return pulumi.get(self, "channel_settings")

    @property
    @pulumi.getter(name="columnDataTypeSettings")
    def column_data_type_settings(self) -> Optional[Sequence['outputs.DiJobJobSettingsColumnDataTypeSetting']]:
        """
        Column type mapping of the synchronization task See `column_data_type_settings` below.
        """
        return pulumi.get(self, "column_data_type_settings")

    @property
    @pulumi.getter(name="cycleScheduleSettings")
    def cycle_schedule_settings(self) -> Optional['outputs.DiJobJobSettingsCycleScheduleSettings']:
        """
        Periodic scheduling settings See `cycle_schedule_settings` below.
        """
        return pulumi.get(self, "cycle_schedule_settings")

    @property
    @pulumi.getter(name="ddlHandlingSettings")
    def ddl_handling_settings(self) -> Optional[Sequence['outputs.DiJobJobSettingsDdlHandlingSetting']]:
        """
        List of DDL processing settings for synchronization tasks See `ddl_handling_settings` below.
        """
        return pulumi.get(self, "ddl_handling_settings")

    @property
    @pulumi.getter(name="runtimeSettings")
    def runtime_settings(self) -> Optional[Sequence['outputs.DiJobJobSettingsRuntimeSetting']]:
        """
        Run-time setting parameter list See `runtime_settings` below.
        """
        return pulumi.get(self, "runtime_settings")


@pulumi.output_type
class DiJobJobSettingsColumnDataTypeSetting(dict):
    @staticmethod
    def __key_warning(key: str):
        suggest = None
        if key == "destinationDataType":
            suggest = "destination_data_type"
        elif key == "sourceDataType":
            suggest = "source_data_type"

        if suggest:
            pulumi.log.warn(f"Key '{key}' not found in DiJobJobSettingsColumnDataTypeSetting. Access the value via the '{suggest}' property getter instead.")

    def __getitem__(self, key: str) -> Any:
        DiJobJobSettingsColumnDataTypeSetting.__key_warning(key)
        return super().__getitem__(key)

    def get(self, key: str, default = None) -> Any:
        DiJobJobSettingsColumnDataTypeSetting.__key_warning(key)
        return super().get(key, default)

    def __init__(__self__, *,
                 destination_data_type: Optional[str] = None,
                 source_data_type: Optional[str] = None):
        """
        :param str destination_data_type: The destination type of the mapping relationship
        :param str source_data_type: The source type of the mapping type
        """
        if destination_data_type is not None:
            pulumi.set(__self__, "destination_data_type", destination_data_type)
        if source_data_type is not None:
            pulumi.set(__self__, "source_data_type", source_data_type)

    @property
    @pulumi.getter(name="destinationDataType")
    def destination_data_type(self) -> Optional[str]:
        """
        The destination type of the mapping relationship
        """
        return pulumi.get(self, "destination_data_type")

    @property
    @pulumi.getter(name="sourceDataType")
    def source_data_type(self) -> Optional[str]:
        """
        The source type of the mapping type
        """
        return pulumi.get(self, "source_data_type")


@pulumi.output_type
class DiJobJobSettingsCycleScheduleSettings(dict):
    @staticmethod
    def __key_warning(key: str):
        suggest = None
        if key == "cycleMigrationType":
            suggest = "cycle_migration_type"
        elif key == "scheduleParameters":
            suggest = "schedule_parameters"

        if suggest:
            pulumi.log.warn(f"Key '{key}' not found in DiJobJobSettingsCycleScheduleSettings. Access the value via the '{suggest}' property getter instead.")

    def __getitem__(self, key: str) -> Any:
        DiJobJobSettingsCycleScheduleSettings.__key_warning(key)
        return super().__getitem__(key)

    def get(self, key: str, default = None) -> Any:
        DiJobJobSettingsCycleScheduleSettings.__key_warning(key)
        return super().get(key, default)

    def __init__(__self__, *,
                 cycle_migration_type: Optional[str] = None,
                 schedule_parameters: Optional[str] = None):
        """
        :param str cycle_migration_type: The type of synchronization that requires periodic scheduling. Value range:
               
               Full: Full
               
               OfflineIncremental: offline increment
        :param str schedule_parameters: Scheduling Parameters
        """
        if cycle_migration_type is not None:
            pulumi.set(__self__, "cycle_migration_type", cycle_migration_type)
        if schedule_parameters is not None:
            pulumi.set(__self__, "schedule_parameters", schedule_parameters)

    @property
    @pulumi.getter(name="cycleMigrationType")
    def cycle_migration_type(self) -> Optional[str]:
        """
        The type of synchronization that requires periodic scheduling. Value range:

        Full: Full

        OfflineIncremental: offline increment
        """
        return pulumi.get(self, "cycle_migration_type")

    @property
    @pulumi.getter(name="scheduleParameters")
    def schedule_parameters(self) -> Optional[str]:
        """
        Scheduling Parameters
        """
        return pulumi.get(self, "schedule_parameters")


@pulumi.output_type
class DiJobJobSettingsDdlHandlingSetting(dict):
    def __init__(__self__, *,
                 action: Optional[str] = None,
                 type: Optional[str] = None):
        """
        :param str type: DDL type, optional enumeration value:
               
               RenameColumn (rename column)
               
               ModifyColumn (rename column)
               
               CreateTable (Rename Column)
               
               TruncateTable (empty table)
               
               DropTable (delete table)
        """
        if action is not None:
            pulumi.set(__self__, "action", action)
        if type is not None:
            pulumi.set(__self__, "type", type)

    @property
    @pulumi.getter
    def action(self) -> Optional[str]:
        return pulumi.get(self, "action")

    @property
    @pulumi.getter
    def type(self) -> Optional[str]:
        """
        DDL type, optional enumeration value:

        RenameColumn (rename column)

        ModifyColumn (rename column)

        CreateTable (Rename Column)

        TruncateTable (empty table)

        DropTable (delete table)
        """
        return pulumi.get(self, "type")


@pulumi.output_type
class DiJobJobSettingsRuntimeSetting(dict):
    def __init__(__self__, *,
                 name: Optional[str] = None,
                 value: Optional[str] = None):
        """
        :param str name: Set name, optional ENUM value:
               
               runtime.offline.speed.limit.mb (valid when runtime.offline.speed.limit.enable = true)
               
               runtime.offline.speed.limit.enable
               
               dst.offline.connection.max (the maximum number of write connections for offline batch tasks)
               
               runtime.offline.concurrent (offline batch synchronization task concurrency)
               
               dst.realtime.connection.max (maximum number of write connections for real-time tasks)
               
               runtime.enable.auto.create.schema (whether to automatically create a schema on the target side)
               
               src.offline.datasource.max.connection (maximum number of source connections for offline batch tasks)
               
               runtime.realtime.concurrent (real-time task concurrency)
        :param str value: Runtime setting value
        """
        if name is not None:
            pulumi.set(__self__, "name", name)
        if value is not None:
            pulumi.set(__self__, "value", value)

    @property
    @pulumi.getter
    def name(self) -> Optional[str]:
        """
        Set name, optional ENUM value:

        runtime.offline.speed.limit.mb (valid when runtime.offline.speed.limit.enable = true)

        runtime.offline.speed.limit.enable

        dst.offline.connection.max (the maximum number of write connections for offline batch tasks)

        runtime.offline.concurrent (offline batch synchronization task concurrency)

        dst.realtime.connection.max (maximum number of write connections for real-time tasks)

        runtime.enable.auto.create.schema (whether to automatically create a schema on the target side)

        src.offline.datasource.max.connection (maximum number of source connections for offline batch tasks)

        runtime.realtime.concurrent (real-time task concurrency)
        """
        return pulumi.get(self, "name")

    @property
    @pulumi.getter
    def value(self) -> Optional[str]:
        """
        Runtime setting value
        """
        return pulumi.get(self, "value")


@pulumi.output_type
class DiJobResourceSettings(dict):
    @staticmethod
    def __key_warning(key: str):
        suggest = None
        if key == "offlineResourceSettings":
            suggest = "offline_resource_settings"
        elif key == "realtimeResourceSettings":
            suggest = "realtime_resource_settings"
        elif key == "scheduleResourceSettings":
            suggest = "schedule_resource_settings"

        if suggest:
            pulumi.log.warn(f"Key '{key}' not found in DiJobResourceSettings. Access the value via the '{suggest}' property getter instead.")

    def __getitem__(self, key: str) -> Any:
        DiJobResourceSettings.__key_warning(key)
        return super().__getitem__(key)

    def get(self, key: str, default = None) -> Any:
        DiJobResourceSettings.__key_warning(key)
        return super().get(key, default)

    def __init__(__self__, *,
                 offline_resource_settings: Optional['outputs.DiJobResourceSettingsOfflineResourceSettings'] = None,
                 realtime_resource_settings: Optional['outputs.DiJobResourceSettingsRealtimeResourceSettings'] = None,
                 schedule_resource_settings: Optional['outputs.DiJobResourceSettingsScheduleResourceSettings'] = None):
        """
        :param 'DiJobResourceSettingsOfflineResourceSettingsArgs' offline_resource_settings: Offline Resource Group configuration See `offline_resource_settings` below.
        :param 'DiJobResourceSettingsRealtimeResourceSettingsArgs' realtime_resource_settings: Real-time Resource Group See `realtime_resource_settings` below.
        :param 'DiJobResourceSettingsScheduleResourceSettingsArgs' schedule_resource_settings: Scheduling Resource Groups See `schedule_resource_settings` below.
        """
        if offline_resource_settings is not None:
            pulumi.set(__self__, "offline_resource_settings", offline_resource_settings)
        if realtime_resource_settings is not None:
            pulumi.set(__self__, "realtime_resource_settings", realtime_resource_settings)
        if schedule_resource_settings is not None:
            pulumi.set(__self__, "schedule_resource_settings", schedule_resource_settings)

    @property
    @pulumi.getter(name="offlineResourceSettings")
    def offline_resource_settings(self) -> Optional['outputs.DiJobResourceSettingsOfflineResourceSettings']:
        """
        Offline Resource Group configuration See `offline_resource_settings` below.
        """
        return pulumi.get(self, "offline_resource_settings")

    @property
    @pulumi.getter(name="realtimeResourceSettings")
    def realtime_resource_settings(self) -> Optional['outputs.DiJobResourceSettingsRealtimeResourceSettings']:
        """
        Real-time Resource Group See `realtime_resource_settings` below.
        """
        return pulumi.get(self, "realtime_resource_settings")

    @property
    @pulumi.getter(name="scheduleResourceSettings")
    def schedule_resource_settings(self) -> Optional['outputs.DiJobResourceSettingsScheduleResourceSettings']:
        """
        Scheduling Resource Groups See `schedule_resource_settings` below.
        """
        return pulumi.get(self, "schedule_resource_settings")


@pulumi.output_type
class DiJobResourceSettingsOfflineResourceSettings(dict):
    @staticmethod
    def __key_warning(key: str):
        suggest = None
        if key == "requestedCu":
            suggest = "requested_cu"
        elif key == "resourceGroupIdentifier":
            suggest = "resource_group_identifier"

        if suggest:
            pulumi.log.warn(f"Key '{key}' not found in DiJobResourceSettingsOfflineResourceSettings. Access the value via the '{suggest}' property getter instead.")

    def __getitem__(self, key: str) -> Any:
        DiJobResourceSettingsOfflineResourceSettings.__key_warning(key)
        return super().__getitem__(key)

    def get(self, key: str, default = None) -> Any:
        DiJobResourceSettingsOfflineResourceSettings.__key_warning(key)
        return super().get(key, default)

    def __init__(__self__, *,
                 requested_cu: Optional[float] = None,
                 resource_group_identifier: Optional[str] = None):
        """
        :param float requested_cu: Scheduling resource group cu
        :param str resource_group_identifier: Scheduling resource group name
        """
        if requested_cu is not None:
            pulumi.set(__self__, "requested_cu", requested_cu)
        if resource_group_identifier is not None:
            pulumi.set(__self__, "resource_group_identifier", resource_group_identifier)

    @property
    @pulumi.getter(name="requestedCu")
    def requested_cu(self) -> Optional[float]:
        """
        Scheduling resource group cu
        """
        return pulumi.get(self, "requested_cu")

    @property
    @pulumi.getter(name="resourceGroupIdentifier")
    def resource_group_identifier(self) -> Optional[str]:
        """
        Scheduling resource group name
        """
        return pulumi.get(self, "resource_group_identifier")


@pulumi.output_type
class DiJobResourceSettingsRealtimeResourceSettings(dict):
    @staticmethod
    def __key_warning(key: str):
        suggest = None
        if key == "requestedCu":
            suggest = "requested_cu"
        elif key == "resourceGroupIdentifier":
            suggest = "resource_group_identifier"

        if suggest:
            pulumi.log.warn(f"Key '{key}' not found in DiJobResourceSettingsRealtimeResourceSettings. Access the value via the '{suggest}' property getter instead.")

    def __getitem__(self, key: str) -> Any:
        DiJobResourceSettingsRealtimeResourceSettings.__key_warning(key)
        return super().__getitem__(key)

    def get(self, key: str, default = None) -> Any:
        DiJobResourceSettingsRealtimeResourceSettings.__key_warning(key)
        return super().get(key, default)

    def __init__(__self__, *,
                 requested_cu: Optional[float] = None,
                 resource_group_identifier: Optional[str] = None):
        """
        :param float requested_cu: Scheduling resource group cu
        :param str resource_group_identifier: Scheduling resource group name
        """
        if requested_cu is not None:
            pulumi.set(__self__, "requested_cu", requested_cu)
        if resource_group_identifier is not None:
            pulumi.set(__self__, "resource_group_identifier", resource_group_identifier)

    @property
    @pulumi.getter(name="requestedCu")
    def requested_cu(self) -> Optional[float]:
        """
        Scheduling resource group cu
        """
        return pulumi.get(self, "requested_cu")

    @property
    @pulumi.getter(name="resourceGroupIdentifier")
    def resource_group_identifier(self) -> Optional[str]:
        """
        Scheduling resource group name
        """
        return pulumi.get(self, "resource_group_identifier")


@pulumi.output_type
class DiJobResourceSettingsScheduleResourceSettings(dict):
    @staticmethod
    def __key_warning(key: str):
        suggest = None
        if key == "requestedCu":
            suggest = "requested_cu"
        elif key == "resourceGroupIdentifier":
            suggest = "resource_group_identifier"

        if suggest:
            pulumi.log.warn(f"Key '{key}' not found in DiJobResourceSettingsScheduleResourceSettings. Access the value via the '{suggest}' property getter instead.")

    def __getitem__(self, key: str) -> Any:
        DiJobResourceSettingsScheduleResourceSettings.__key_warning(key)
        return super().__getitem__(key)

    def get(self, key: str, default = None) -> Any:
        DiJobResourceSettingsScheduleResourceSettings.__key_warning(key)
        return super().get(key, default)

    def __init__(__self__, *,
                 requested_cu: Optional[float] = None,
                 resource_group_identifier: Optional[str] = None):
        """
        :param float requested_cu: Scheduling resource group cu
        :param str resource_group_identifier: Scheduling resource group name
        """
        if requested_cu is not None:
            pulumi.set(__self__, "requested_cu", requested_cu)
        if resource_group_identifier is not None:
            pulumi.set(__self__, "resource_group_identifier", resource_group_identifier)

    @property
    @pulumi.getter(name="requestedCu")
    def requested_cu(self) -> Optional[float]:
        """
        Scheduling resource group cu
        """
        return pulumi.get(self, "requested_cu")

    @property
    @pulumi.getter(name="resourceGroupIdentifier")
    def resource_group_identifier(self) -> Optional[str]:
        """
        Scheduling resource group name
        """
        return pulumi.get(self, "resource_group_identifier")


@pulumi.output_type
class DiJobSourceDataSourceSetting(dict):
    @staticmethod
    def __key_warning(key: str):
        suggest = None
        if key == "dataSourceName":
            suggest = "data_source_name"
        elif key == "dataSourceProperties":
            suggest = "data_source_properties"

        if suggest:
            pulumi.log.warn(f"Key '{key}' not found in DiJobSourceDataSourceSetting. Access the value via the '{suggest}' property getter instead.")

    def __getitem__(self, key: str) -> Any:
        DiJobSourceDataSourceSetting.__key_warning(key)
        return super().__getitem__(key)

    def get(self, key: str, default = None) -> Any:
        DiJobSourceDataSourceSetting.__key_warning(key)
        return super().get(key, default)

    def __init__(__self__, *,
                 data_source_name: Optional[str] = None,
                 data_source_properties: Optional['outputs.DiJobSourceDataSourceSettingDataSourceProperties'] = None):
        """
        :param str data_source_name: Data source name of a single source
        :param 'DiJobSourceDataSourceSettingDataSourcePropertiesArgs' data_source_properties: Single Source Data Source Properties See `data_source_properties` below.
        """
        if data_source_name is not None:
            pulumi.set(__self__, "data_source_name", data_source_name)
        if data_source_properties is not None:
            pulumi.set(__self__, "data_source_properties", data_source_properties)

    @property
    @pulumi.getter(name="dataSourceName")
    def data_source_name(self) -> Optional[str]:
        """
        Data source name of a single source
        """
        return pulumi.get(self, "data_source_name")

    @property
    @pulumi.getter(name="dataSourceProperties")
    def data_source_properties(self) -> Optional['outputs.DiJobSourceDataSourceSettingDataSourceProperties']:
        """
        Single Source Data Source Properties See `data_source_properties` below.
        """
        return pulumi.get(self, "data_source_properties")


@pulumi.output_type
class DiJobSourceDataSourceSettingDataSourceProperties(dict):
    def __init__(__self__, *,
                 encoding: Optional[str] = None,
                 timezone: Optional[str] = None):
        """
        :param str encoding: Data Source Encoding
        :param str timezone: Data Source Time Zone
        """
        if encoding is not None:
            pulumi.set(__self__, "encoding", encoding)
        if timezone is not None:
            pulumi.set(__self__, "timezone", timezone)

    @property
    @pulumi.getter
    def encoding(self) -> Optional[str]:
        """
        Data Source Encoding
        """
        return pulumi.get(self, "encoding")

    @property
    @pulumi.getter
    def timezone(self) -> Optional[str]:
        """
        Data Source Time Zone
        """
        return pulumi.get(self, "timezone")


@pulumi.output_type
class DiJobTableMapping(dict):
    @staticmethod
    def __key_warning(key: str):
        suggest = None
        if key == "sourceObjectSelectionRules":
            suggest = "source_object_selection_rules"
        elif key == "transformationRules":
            suggest = "transformation_rules"

        if suggest:
            pulumi.log.warn(f"Key '{key}' not found in DiJobTableMapping. Access the value via the '{suggest}' property getter instead.")

    def __getitem__(self, key: str) -> Any:
        DiJobTableMapping.__key_warning(key)
        return super().__getitem__(key)

    def get(self, key: str, default = None) -> Any:
        DiJobTableMapping.__key_warning(key)
        return super().get(key, default)

    def __init__(__self__, *,
                 source_object_selection_rules: Optional[Sequence['outputs.DiJobTableMappingSourceObjectSelectionRule']] = None,
                 transformation_rules: Optional[Sequence['outputs.DiJobTableMappingTransformationRule']] = None):
        """
        :param Sequence['DiJobTableMappingSourceObjectSelectionRuleArgs'] source_object_selection_rules: Each rule can select different types of source objects to be synchronized, such as source database and source data table. See `source_object_selection_rules` below.
        :param Sequence['DiJobTableMappingTransformationRuleArgs'] transformation_rules: A list of conversion rule definitions for a synchronization object. Each element in the list defines a conversion rule. See `transformation_rules` below.
        """
        if source_object_selection_rules is not None:
            pulumi.set(__self__, "source_object_selection_rules", source_object_selection_rules)
        if transformation_rules is not None:
            pulumi.set(__self__, "transformation_rules", transformation_rules)

    @property
    @pulumi.getter(name="sourceObjectSelectionRules")
    def source_object_selection_rules(self) -> Optional[Sequence['outputs.DiJobTableMappingSourceObjectSelectionRule']]:
        """
        Each rule can select different types of source objects to be synchronized, such as source database and source data table. See `source_object_selection_rules` below.
        """
        return pulumi.get(self, "source_object_selection_rules")

    @property
    @pulumi.getter(name="transformationRules")
    def transformation_rules(self) -> Optional[Sequence['outputs.DiJobTableMappingTransformationRule']]:
        """
        A list of conversion rule definitions for a synchronization object. Each element in the list defines a conversion rule. See `transformation_rules` below.
        """
        return pulumi.get(self, "transformation_rules")


@pulumi.output_type
class DiJobTableMappingSourceObjectSelectionRule(dict):
    @staticmethod
    def __key_warning(key: str):
        suggest = None
        if key == "expressionType":
            suggest = "expression_type"
        elif key == "objectType":
            suggest = "object_type"

        if suggest:
            pulumi.log.warn(f"Key '{key}' not found in DiJobTableMappingSourceObjectSelectionRule. Access the value via the '{suggest}' property getter instead.")

    def __getitem__(self, key: str) -> Any:
        DiJobTableMappingSourceObjectSelectionRule.__key_warning(key)
        return super().__getitem__(key)

    def get(self, key: str, default = None) -> Any:
        DiJobTableMappingSourceObjectSelectionRule.__key_warning(key)
        return super().get(key, default)

    def __init__(__self__, *,
                 action: Optional[str] = None,
                 expression: Optional[str] = None,
                 expression_type: Optional[str] = None,
                 object_type: Optional[str] = None):
        """
        :param str expression: Expression, such as mysql_table_1
        :param str expression_type: Expression type, value range: Exact/Regex
        :param str object_type: Object type, optional enumeration value:
               
               Table (Table)
               
               Database
        """
        if action is not None:
            pulumi.set(__self__, "action", action)
        if expression is not None:
            pulumi.set(__self__, "expression", expression)
        if expression_type is not None:
            pulumi.set(__self__, "expression_type", expression_type)
        if object_type is not None:
            pulumi.set(__self__, "object_type", object_type)

    @property
    @pulumi.getter
    def action(self) -> Optional[str]:
        return pulumi.get(self, "action")

    @property
    @pulumi.getter
    def expression(self) -> Optional[str]:
        """
        Expression, such as mysql_table_1
        """
        return pulumi.get(self, "expression")

    @property
    @pulumi.getter(name="expressionType")
    def expression_type(self) -> Optional[str]:
        """
        Expression type, value range: Exact/Regex
        """
        return pulumi.get(self, "expression_type")

    @property
    @pulumi.getter(name="objectType")
    def object_type(self) -> Optional[str]:
        """
        Object type, optional enumeration value:

        Table (Table)

        Database
        """
        return pulumi.get(self, "object_type")


@pulumi.output_type
class DiJobTableMappingTransformationRule(dict):
    @staticmethod
    def __key_warning(key: str):
        suggest = None
        if key == "ruleActionType":
            suggest = "rule_action_type"
        elif key == "ruleName":
            suggest = "rule_name"
        elif key == "ruleTargetType":
            suggest = "rule_target_type"

        if suggest:
            pulumi.log.warn(f"Key '{key}' not found in DiJobTableMappingTransformationRule. Access the value via the '{suggest}' property getter instead.")

    def __getitem__(self, key: str) -> Any:
        DiJobTableMappingTransformationRule.__key_warning(key)
        return super().__getitem__(key)

    def get(self, key: str, default = None) -> Any:
        DiJobTableMappingTransformationRule.__key_warning(key)
        return super().get(key, default)

    def __init__(__self__, *,
                 rule_action_type: Optional[str] = None,
                 rule_name: Optional[str] = None,
                 rule_target_type: Optional[str] = None):
        """
        :param str rule_action_type: Action type, optional enumeration value:
               
               DefinePrimaryKey (defines the primary key)
               
               Rename
               
               AddColumn (increase column)
               
               HandleDml(DML handling)
               
               DefineIncrementalCondition
        :param str rule_name: Rule Name
        :param str rule_target_type: Target type of action, optional enumeration value:
               
               Table (Table)
               
               Schema(schema)
        """
        if rule_action_type is not None:
            pulumi.set(__self__, "rule_action_type", rule_action_type)
        if rule_name is not None:
            pulumi.set(__self__, "rule_name", rule_name)
        if rule_target_type is not None:
            pulumi.set(__self__, "rule_target_type", rule_target_type)

    @property
    @pulumi.getter(name="ruleActionType")
    def rule_action_type(self) -> Optional[str]:
        """
        Action type, optional enumeration value:

        DefinePrimaryKey (defines the primary key)

        Rename

        AddColumn (increase column)

        HandleDml(DML handling)

        DefineIncrementalCondition
        """
        return pulumi.get(self, "rule_action_type")

    @property
    @pulumi.getter(name="ruleName")
    def rule_name(self) -> Optional[str]:
        """
        Rule Name
        """
        return pulumi.get(self, "rule_name")

    @property
    @pulumi.getter(name="ruleTargetType")
    def rule_target_type(self) -> Optional[str]:
        """
        Target type of action, optional enumeration value:

        Table (Table)

        Schema(schema)
        """
        return pulumi.get(self, "rule_target_type")


@pulumi.output_type
class DiJobTransformationRule(dict):
    @staticmethod
    def __key_warning(key: str):
        suggest = None
        if key == "ruleActionType":
            suggest = "rule_action_type"
        elif key == "ruleExpression":
            suggest = "rule_expression"
        elif key == "ruleName":
            suggest = "rule_name"
        elif key == "ruleTargetType":
            suggest = "rule_target_type"

        if suggest:
            pulumi.log.warn(f"Key '{key}' not found in DiJobTransformationRule. Access the value via the '{suggest}' property getter instead.")

    def __getitem__(self, key: str) -> Any:
        DiJobTransformationRule.__key_warning(key)
        return super().__getitem__(key)

    def get(self, key: str, default = None) -> Any:
        DiJobTransformationRule.__key_warning(key)
        return super().get(key, default)

    def __init__(__self__, *,
                 rule_action_type: Optional[str] = None,
                 rule_expression: Optional[str] = None,
                 rule_name: Optional[str] = None,
                 rule_target_type: Optional[str] = None):
        """
        :param str rule_action_type: Action type, optional enumeration value:
               
               DefinePrimaryKey (defines the primary key)
               
               Rename
               
               AddColumn (increase column)
               
               HandleDml(DML handling)
               
               DefineIncrementalCondition
        :param str rule_expression: Regular expression, in json string format.
               
               Example renaming rule (Rename): {"expression":"${srcDatasourceName}_${srcDatabaseName}_0922","variables":[{"variableName":"srcDatabaseName","variableRules":[{"from":"fromdb","to":"todb"}]}]}
        :param str rule_name: Rule Name
        :param str rule_target_type: Target type of action, optional enumeration value:
               
               Table (Table)
               
               Schema(schema)
        """
        if rule_action_type is not None:
            pulumi.set(__self__, "rule_action_type", rule_action_type)
        if rule_expression is not None:
            pulumi.set(__self__, "rule_expression", rule_expression)
        if rule_name is not None:
            pulumi.set(__self__, "rule_name", rule_name)
        if rule_target_type is not None:
            pulumi.set(__self__, "rule_target_type", rule_target_type)

    @property
    @pulumi.getter(name="ruleActionType")
    def rule_action_type(self) -> Optional[str]:
        """
        Action type, optional enumeration value:

        DefinePrimaryKey (defines the primary key)

        Rename

        AddColumn (increase column)

        HandleDml(DML handling)

        DefineIncrementalCondition
        """
        return pulumi.get(self, "rule_action_type")

    @property
    @pulumi.getter(name="ruleExpression")
    def rule_expression(self) -> Optional[str]:
        """
        Regular expression, in json string format.

        Example renaming rule (Rename): {"expression":"${srcDatasourceName}_${srcDatabaseName}_0922","variables":[{"variableName":"srcDatabaseName","variableRules":[{"from":"fromdb","to":"todb"}]}]}
        """
        return pulumi.get(self, "rule_expression")

    @property
    @pulumi.getter(name="ruleName")
    def rule_name(self) -> Optional[str]:
        """
        Rule Name
        """
        return pulumi.get(self, "rule_name")

    @property
    @pulumi.getter(name="ruleTargetType")
    def rule_target_type(self) -> Optional[str]:
        """
        Target type of action, optional enumeration value:

        Table (Table)

        Schema(schema)
        """
        return pulumi.get(self, "rule_target_type")


@pulumi.output_type
class ProjectMemberRole(dict):
    def __init__(__self__, *,
                 code: Optional[str] = None,
                 name: Optional[str] = None,
                 type: Optional[str] = None):
        """
        :param str code: Project Role Code.
        :param str name: project role name
        :param str type: project role type
        """
        if code is not None:
            pulumi.set(__self__, "code", code)
        if name is not None:
            pulumi.set(__self__, "name", name)
        if type is not None:
            pulumi.set(__self__, "type", type)

    @property
    @pulumi.getter
    def code(self) -> Optional[str]:
        """
        Project Role Code.
        """
        return pulumi.get(self, "code")

    @property
    @pulumi.getter
    def name(self) -> Optional[str]:
        """
        project role name
        """
        return pulumi.get(self, "name")

    @property
    @pulumi.getter
    def type(self) -> Optional[str]:
        """
        project role type
        """
        return pulumi.get(self, "type")


@pulumi.output_type
class GetFoldersFolderResult(dict):
    def __init__(__self__, *,
                 folder_id: str,
                 folder_path: str,
                 id: str,
                 project_id: str):
        """
        :param str folder_path: Folder Path.
        :param str id: The Folder ID.
        :param str project_id: The ID of the project.
        """
        pulumi.set(__self__, "folder_id", folder_id)
        pulumi.set(__self__, "folder_path", folder_path)
        pulumi.set(__self__, "id", id)
        pulumi.set(__self__, "project_id", project_id)

    @property
    @pulumi.getter(name="folderId")
    def folder_id(self) -> str:
        return pulumi.get(self, "folder_id")

    @property
    @pulumi.getter(name="folderPath")
    def folder_path(self) -> str:
        """
        Folder Path.
        """
        return pulumi.get(self, "folder_path")

    @property
    @pulumi.getter
    def id(self) -> str:
        """
        The Folder ID.
        """
        return pulumi.get(self, "id")

    @property
    @pulumi.getter(name="projectId")
    def project_id(self) -> str:
        """
        The ID of the project.
        """
        return pulumi.get(self, "project_id")





# coding=utf-8
# *** WARNING: this file was generated by the Pulumi Terraform Bridge (tfgen) Tool. ***
# *** Do not edit by hand unless you're certain you know what you are doing! ***

import copy
import warnings
import sys
import pulumi
import pulumi.runtime
from typing import Any, Mapping, Optional, Sequence, Union, overload
if sys.version_info >= (3, 11):
    from typing import NotRequired, TypedDict, TypeAlias
else:
    from typing_extensions import NotRequired, TypedDict, TypeAlias
from .. import _utilities

__all__ = ['DwResourceGroupArgs', 'DwResourceGroup']

@pulumi.input_type
class DwResourceGroupArgs:
    def __init__(__self__, *,
                 default_vpc_id: pulumi.Input[str],
                 default_vswitch_id: pulumi.Input[str],
                 remark: pulumi.Input[str],
                 auto_renew: Optional[pulumi.Input[bool]] = None,
                 payment_duration: Optional[pulumi.Input[int]] = None,
                 payment_duration_unit: Optional[pulumi.Input[str]] = None,
                 payment_type: Optional[pulumi.Input[str]] = None,
                 resource_group_id: Optional[pulumi.Input[str]] = None,
                 resource_group_name: Optional[pulumi.Input[str]] = None,
                 specification: Optional[pulumi.Input[int]] = None,
                 tags: Optional[pulumi.Input[Mapping[str, pulumi.Input[str]]]] = None):
        """
        The set of arguments for constructing a DwResourceGroup resource.
        :param pulumi.Input[str] default_vpc_id: The VPC ID of the default network resource.
        :param pulumi.Input[str] default_vswitch_id: The ID of the vswitch bound to the network resource by default.
        :param pulumi.Input[str] remark: Resource Group Comments
        :param pulumi.Input[bool] auto_renew: Whether to automatically renew. The default value is false.
        :param pulumi.Input[int] payment_duration: When the payment method is Prepaid, the unit is PaymentDurationUnit.
        :param pulumi.Input[str] payment_duration_unit: When the payment method is Prepaid, the payment duration unit, Month is Month, Year is Year, and there is no other optional value.
        :param pulumi.Input[str] payment_type: The billing type of the resource group. PrePaid is Subscription, and PostPaid is Pay-As-You-Go.
        :param pulumi.Input[str] resource_group_id: The ID of the resource group
        :param pulumi.Input[str] resource_group_name: Resource group name
        :param pulumi.Input[int] specification: Package year and package month resource group specifications, unit CU
        :param pulumi.Input[Mapping[str, pulumi.Input[str]]] tags: The tag of the resource
        """
        pulumi.set(__self__, "default_vpc_id", default_vpc_id)
        pulumi.set(__self__, "default_vswitch_id", default_vswitch_id)
        pulumi.set(__self__, "remark", remark)
        if auto_renew is not None:
            pulumi.set(__self__, "auto_renew", auto_renew)
        if payment_duration is not None:
            pulumi.set(__self__, "payment_duration", payment_duration)
        if payment_duration_unit is not None:
            pulumi.set(__self__, "payment_duration_unit", payment_duration_unit)
        if payment_type is not None:
            pulumi.set(__self__, "payment_type", payment_type)
        if resource_group_id is not None:
            pulumi.set(__self__, "resource_group_id", resource_group_id)
        if resource_group_name is not None:
            pulumi.set(__self__, "resource_group_name", resource_group_name)
        if specification is not None:
            pulumi.set(__self__, "specification", specification)
        if tags is not None:
            pulumi.set(__self__, "tags", tags)

    @property
    @pulumi.getter(name="defaultVpcId")
    def default_vpc_id(self) -> pulumi.Input[str]:
        """
        The VPC ID of the default network resource.
        """
        return pulumi.get(self, "default_vpc_id")

    @default_vpc_id.setter
    def default_vpc_id(self, value: pulumi.Input[str]):
        pulumi.set(self, "default_vpc_id", value)

    @property
    @pulumi.getter(name="defaultVswitchId")
    def default_vswitch_id(self) -> pulumi.Input[str]:
        """
        The ID of the vswitch bound to the network resource by default.
        """
        return pulumi.get(self, "default_vswitch_id")

    @default_vswitch_id.setter
    def default_vswitch_id(self, value: pulumi.Input[str]):
        pulumi.set(self, "default_vswitch_id", value)

    @property
    @pulumi.getter
    def remark(self) -> pulumi.Input[str]:
        """
        Resource Group Comments
        """
        return pulumi.get(self, "remark")

    @remark.setter
    def remark(self, value: pulumi.Input[str]):
        pulumi.set(self, "remark", value)

    @property
    @pulumi.getter(name="autoRenew")
    def auto_renew(self) -> Optional[pulumi.Input[bool]]:
        """
        Whether to automatically renew. The default value is false.
        """
        return pulumi.get(self, "auto_renew")

    @auto_renew.setter
    def auto_renew(self, value: Optional[pulumi.Input[bool]]):
        pulumi.set(self, "auto_renew", value)

    @property
    @pulumi.getter(name="paymentDuration")
    def payment_duration(self) -> Optional[pulumi.Input[int]]:
        """
        When the payment method is Prepaid, the unit is PaymentDurationUnit.
        """
        return pulumi.get(self, "payment_duration")

    @payment_duration.setter
    def payment_duration(self, value: Optional[pulumi.Input[int]]):
        pulumi.set(self, "payment_duration", value)

    @property
    @pulumi.getter(name="paymentDurationUnit")
    def payment_duration_unit(self) -> Optional[pulumi.Input[str]]:
        """
        When the payment method is Prepaid, the payment duration unit, Month is Month, Year is Year, and there is no other optional value.
        """
        return pulumi.get(self, "payment_duration_unit")

    @payment_duration_unit.setter
    def payment_duration_unit(self, value: Optional[pulumi.Input[str]]):
        pulumi.set(self, "payment_duration_unit", value)

    @property
    @pulumi.getter(name="paymentType")
    def payment_type(self) -> Optional[pulumi.Input[str]]:
        """
        The billing type of the resource group. PrePaid is Subscription, and PostPaid is Pay-As-You-Go.
        """
        return pulumi.get(self, "payment_type")

    @payment_type.setter
    def payment_type(self, value: Optional[pulumi.Input[str]]):
        pulumi.set(self, "payment_type", value)

    @property
    @pulumi.getter(name="resourceGroupId")
    def resource_group_id(self) -> Optional[pulumi.Input[str]]:
        """
        The ID of the resource group
        """
        return pulumi.get(self, "resource_group_id")

    @resource_group_id.setter
    def resource_group_id(self, value: Optional[pulumi.Input[str]]):
        pulumi.set(self, "resource_group_id", value)

    @property
    @pulumi.getter(name="resourceGroupName")
    def resource_group_name(self) -> Optional[pulumi.Input[str]]:
        """
        Resource group name
        """
        return pulumi.get(self, "resource_group_name")

    @resource_group_name.setter
    def resource_group_name(self, value: Optional[pulumi.Input[str]]):
        pulumi.set(self, "resource_group_name", value)

    @property
    @pulumi.getter
    def specification(self) -> Optional[pulumi.Input[int]]:
        """
        Package year and package month resource group specifications, unit CU
        """
        return pulumi.get(self, "specification")

    @specification.setter
    def specification(self, value: Optional[pulumi.Input[int]]):
        pulumi.set(self, "specification", value)

    @property
    @pulumi.getter
    def tags(self) -> Optional[pulumi.Input[Mapping[str, pulumi.Input[str]]]]:
        """
        The tag of the resource
        """
        return pulumi.get(self, "tags")

    @tags.setter
    def tags(self, value: Optional[pulumi.Input[Mapping[str, pulumi.Input[str]]]]):
        pulumi.set(self, "tags", value)


@pulumi.input_type
class _DwResourceGroupState:
    def __init__(__self__, *,
                 auto_renew: Optional[pulumi.Input[bool]] = None,
                 create_time: Optional[pulumi.Input[int]] = None,
                 default_vpc_id: Optional[pulumi.Input[str]] = None,
                 default_vswitch_id: Optional[pulumi.Input[str]] = None,
                 payment_duration: Optional[pulumi.Input[int]] = None,
                 payment_duration_unit: Optional[pulumi.Input[str]] = None,
                 payment_type: Optional[pulumi.Input[str]] = None,
                 remark: Optional[pulumi.Input[str]] = None,
                 resource_group_id: Optional[pulumi.Input[str]] = None,
                 resource_group_name: Optional[pulumi.Input[str]] = None,
                 specification: Optional[pulumi.Input[int]] = None,
                 status: Optional[pulumi.Input[str]] = None,
                 tags: Optional[pulumi.Input[Mapping[str, pulumi.Input[str]]]] = None):
        """
        Input properties used for looking up and filtering DwResourceGroup resources.
        :param pulumi.Input[bool] auto_renew: Whether to automatically renew. The default value is false.
        :param pulumi.Input[int] create_time: Resource group creation time
        :param pulumi.Input[str] default_vpc_id: The VPC ID of the default network resource.
        :param pulumi.Input[str] default_vswitch_id: The ID of the vswitch bound to the network resource by default.
        :param pulumi.Input[int] payment_duration: When the payment method is Prepaid, the unit is PaymentDurationUnit.
        :param pulumi.Input[str] payment_duration_unit: When the payment method is Prepaid, the payment duration unit, Month is Month, Year is Year, and there is no other optional value.
        :param pulumi.Input[str] payment_type: The billing type of the resource group. PrePaid is Subscription, and PostPaid is Pay-As-You-Go.
        :param pulumi.Input[str] remark: Resource Group Comments
        :param pulumi.Input[str] resource_group_id: The ID of the resource group
        :param pulumi.Input[str] resource_group_name: Resource group name
        :param pulumi.Input[int] specification: Package year and package month resource group specifications, unit CU
        :param pulumi.Input[str] status: Resource group status:
        :param pulumi.Input[Mapping[str, pulumi.Input[str]]] tags: The tag of the resource
        """
        if auto_renew is not None:
            pulumi.set(__self__, "auto_renew", auto_renew)
        if create_time is not None:
            pulumi.set(__self__, "create_time", create_time)
        if default_vpc_id is not None:
            pulumi.set(__self__, "default_vpc_id", default_vpc_id)
        if default_vswitch_id is not None:
            pulumi.set(__self__, "default_vswitch_id", default_vswitch_id)
        if payment_duration is not None:
            pulumi.set(__self__, "payment_duration", payment_duration)
        if payment_duration_unit is not None:
            pulumi.set(__self__, "payment_duration_unit", payment_duration_unit)
        if payment_type is not None:
            pulumi.set(__self__, "payment_type", payment_type)
        if remark is not None:
            pulumi.set(__self__, "remark", remark)
        if resource_group_id is not None:
            pulumi.set(__self__, "resource_group_id", resource_group_id)
        if resource_group_name is not None:
            pulumi.set(__self__, "resource_group_name", resource_group_name)
        if specification is not None:
            pulumi.set(__self__, "specification", specification)
        if status is not None:
            pulumi.set(__self__, "status", status)
        if tags is not None:
            pulumi.set(__self__, "tags", tags)

    @property
    @pulumi.getter(name="autoRenew")
    def auto_renew(self) -> Optional[pulumi.Input[bool]]:
        """
        Whether to automatically renew. The default value is false.
        """
        return pulumi.get(self, "auto_renew")

    @auto_renew.setter
    def auto_renew(self, value: Optional[pulumi.Input[bool]]):
        pulumi.set(self, "auto_renew", value)

    @property
    @pulumi.getter(name="createTime")
    def create_time(self) -> Optional[pulumi.Input[int]]:
        """
        Resource group creation time
        """
        return pulumi.get(self, "create_time")

    @create_time.setter
    def create_time(self, value: Optional[pulumi.Input[int]]):
        pulumi.set(self, "create_time", value)

    @property
    @pulumi.getter(name="defaultVpcId")
    def default_vpc_id(self) -> Optional[pulumi.Input[str]]:
        """
        The VPC ID of the default network resource.
        """
        return pulumi.get(self, "default_vpc_id")

    @default_vpc_id.setter
    def default_vpc_id(self, value: Optional[pulumi.Input[str]]):
        pulumi.set(self, "default_vpc_id", value)

    @property
    @pulumi.getter(name="defaultVswitchId")
    def default_vswitch_id(self) -> Optional[pulumi.Input[str]]:
        """
        The ID of the vswitch bound to the network resource by default.
        """
        return pulumi.get(self, "default_vswitch_id")

    @default_vswitch_id.setter
    def default_vswitch_id(self, value: Optional[pulumi.Input[str]]):
        pulumi.set(self, "default_vswitch_id", value)

    @property
    @pulumi.getter(name="paymentDuration")
    def payment_duration(self) -> Optional[pulumi.Input[int]]:
        """
        When the payment method is Prepaid, the unit is PaymentDurationUnit.
        """
        return pulumi.get(self, "payment_duration")

    @payment_duration.setter
    def payment_duration(self, value: Optional[pulumi.Input[int]]):
        pulumi.set(self, "payment_duration", value)

    @property
    @pulumi.getter(name="paymentDurationUnit")
    def payment_duration_unit(self) -> Optional[pulumi.Input[str]]:
        """
        When the payment method is Prepaid, the payment duration unit, Month is Month, Year is Year, and there is no other optional value.
        """
        return pulumi.get(self, "payment_duration_unit")

    @payment_duration_unit.setter
    def payment_duration_unit(self, value: Optional[pulumi.Input[str]]):
        pulumi.set(self, "payment_duration_unit", value)

    @property
    @pulumi.getter(name="paymentType")
    def payment_type(self) -> Optional[pulumi.Input[str]]:
        """
        The billing type of the resource group. PrePaid is Subscription, and PostPaid is Pay-As-You-Go.
        """
        return pulumi.get(self, "payment_type")

    @payment_type.setter
    def payment_type(self, value: Optional[pulumi.Input[str]]):
        pulumi.set(self, "payment_type", value)

    @property
    @pulumi.getter
    def remark(self) -> Optional[pulumi.Input[str]]:
        """
        Resource Group Comments
        """
        return pulumi.get(self, "remark")

    @remark.setter
    def remark(self, value: Optional[pulumi.Input[str]]):
        pulumi.set(self, "remark", value)

    @property
    @pulumi.getter(name="resourceGroupId")
    def resource_group_id(self) -> Optional[pulumi.Input[str]]:
        """
        The ID of the resource group
        """
        return pulumi.get(self, "resource_group_id")

    @resource_group_id.setter
    def resource_group_id(self, value: Optional[pulumi.Input[str]]):
        pulumi.set(self, "resource_group_id", value)

    @property
    @pulumi.getter(name="resourceGroupName")
    def resource_group_name(self) -> Optional[pulumi.Input[str]]:
        """
        Resource group name
        """
        return pulumi.get(self, "resource_group_name")

    @resource_group_name.setter
    def resource_group_name(self, value: Optional[pulumi.Input[str]]):
        pulumi.set(self, "resource_group_name", value)

    @property
    @pulumi.getter
    def specification(self) -> Optional[pulumi.Input[int]]:
        """
        Package year and package month resource group specifications, unit CU
        """
        return pulumi.get(self, "specification")

    @specification.setter
    def specification(self, value: Optional[pulumi.Input[int]]):
        pulumi.set(self, "specification", value)

    @property
    @pulumi.getter
    def status(self) -> Optional[pulumi.Input[str]]:
        """
        Resource group status:
        """
        return pulumi.get(self, "status")

    @status.setter
    def status(self, value: Optional[pulumi.Input[str]]):
        pulumi.set(self, "status", value)

    @property
    @pulumi.getter
    def tags(self) -> Optional[pulumi.Input[Mapping[str, pulumi.Input[str]]]]:
        """
        The tag of the resource
        """
        return pulumi.get(self, "tags")

    @tags.setter
    def tags(self, value: Optional[pulumi.Input[Mapping[str, pulumi.Input[str]]]]):
        pulumi.set(self, "tags", value)


class DwResourceGroup(pulumi.CustomResource):
    @overload
    def __init__(__self__,
                 resource_name: str,
                 opts: Optional[pulumi.ResourceOptions] = None,
                 auto_renew: Optional[pulumi.Input[bool]] = None,
                 default_vpc_id: Optional[pulumi.Input[str]] = None,
                 default_vswitch_id: Optional[pulumi.Input[str]] = None,
                 payment_duration: Optional[pulumi.Input[int]] = None,
                 payment_duration_unit: Optional[pulumi.Input[str]] = None,
                 payment_type: Optional[pulumi.Input[str]] = None,
                 remark: Optional[pulumi.Input[str]] = None,
                 resource_group_id: Optional[pulumi.Input[str]] = None,
                 resource_group_name: Optional[pulumi.Input[str]] = None,
                 specification: Optional[pulumi.Input[int]] = None,
                 tags: Optional[pulumi.Input[Mapping[str, pulumi.Input[str]]]] = None,
                 __props__=None):
        """
        Provides a Data Works Dw Resource Group resource.

        For information about Data Works Dw Resource Group and how to use it, see [What is Dw Resource Group](https://www.alibabacloud.com/help/en/).

        > **NOTE:** Available since v1.241.0.

        ## Import

        Data Works Dw Resource Group can be imported using the id, e.g.

        ```sh
        $ pulumi import alicloud:dataworks/dwResourceGroup:DwResourceGroup example <id>
        ```

        :param str resource_name: The name of the resource.
        :param pulumi.ResourceOptions opts: Options for the resource.
        :param pulumi.Input[bool] auto_renew: Whether to automatically renew. The default value is false.
        :param pulumi.Input[str] default_vpc_id: The VPC ID of the default network resource.
        :param pulumi.Input[str] default_vswitch_id: The ID of the vswitch bound to the network resource by default.
        :param pulumi.Input[int] payment_duration: When the payment method is Prepaid, the unit is PaymentDurationUnit.
        :param pulumi.Input[str] payment_duration_unit: When the payment method is Prepaid, the payment duration unit, Month is Month, Year is Year, and there is no other optional value.
        :param pulumi.Input[str] payment_type: The billing type of the resource group. PrePaid is Subscription, and PostPaid is Pay-As-You-Go.
        :param pulumi.Input[str] remark: Resource Group Comments
        :param pulumi.Input[str] resource_group_id: The ID of the resource group
        :param pulumi.Input[str] resource_group_name: Resource group name
        :param pulumi.Input[int] specification: Package year and package month resource group specifications, unit CU
        :param pulumi.Input[Mapping[str, pulumi.Input[str]]] tags: The tag of the resource
        """
        ...
    @overload
    def __init__(__self__,
                 resource_name: str,
                 args: DwResourceGroupArgs,
                 opts: Optional[pulumi.ResourceOptions] = None):
        """
        Provides a Data Works Dw Resource Group resource.

        For information about Data Works Dw Resource Group and how to use it, see [What is Dw Resource Group](https://www.alibabacloud.com/help/en/).

        > **NOTE:** Available since v1.241.0.

        ## Import

        Data Works Dw Resource Group can be imported using the id, e.g.

        ```sh
        $ pulumi import alicloud:dataworks/dwResourceGroup:DwResourceGroup example <id>
        ```

        :param str resource_name: The name of the resource.
        :param DwResourceGroupArgs args: The arguments to use to populate this resource's properties.
        :param pulumi.ResourceOptions opts: Options for the resource.
        """
        ...
    def __init__(__self__, resource_name: str, *args, **kwargs):
        resource_args, opts = _utilities.get_resource_args_opts(DwResourceGroupArgs, pulumi.ResourceOptions, *args, **kwargs)
        if resource_args is not None:
            __self__._internal_init(resource_name, opts, **resource_args.__dict__)
        else:
            __self__._internal_init(resource_name, *args, **kwargs)

    def _internal_init(__self__,
                 resource_name: str,
                 opts: Optional[pulumi.ResourceOptions] = None,
                 auto_renew: Optional[pulumi.Input[bool]] = None,
                 default_vpc_id: Optional[pulumi.Input[str]] = None,
                 default_vswitch_id: Optional[pulumi.Input[str]] = None,
                 payment_duration: Optional[pulumi.Input[int]] = None,
                 payment_duration_unit: Optional[pulumi.Input[str]] = None,
                 payment_type: Optional[pulumi.Input[str]] = None,
                 remark: Optional[pulumi.Input[str]] = None,
                 resource_group_id: Optional[pulumi.Input[str]] = None,
                 resource_group_name: Optional[pulumi.Input[str]] = None,
                 specification: Optional[pulumi.Input[int]] = None,
                 tags: Optional[pulumi.Input[Mapping[str, pulumi.Input[str]]]] = None,
                 __props__=None):
        opts = pulumi.ResourceOptions.merge(_utilities.get_resource_opts_defaults(), opts)
        if not isinstance(opts, pulumi.ResourceOptions):
            raise TypeError('Expected resource options to be a ResourceOptions instance')
        if opts.id is None:
            if __props__ is not None:
                raise TypeError('__props__ is only valid when passed in combination with a valid opts.id to get an existing resource')
            __props__ = DwResourceGroupArgs.__new__(DwResourceGroupArgs)

            __props__.__dict__["auto_renew"] = auto_renew
            if default_vpc_id is None and not opts.urn:
                raise TypeError("Missing required property 'default_vpc_id'")
            __props__.__dict__["default_vpc_id"] = default_vpc_id
            if default_vswitch_id is None and not opts.urn:
                raise TypeError("Missing required property 'default_vswitch_id'")
            __props__.__dict__["default_vswitch_id"] = default_vswitch_id
            __props__.__dict__["payment_duration"] = payment_duration
            __props__.__dict__["payment_duration_unit"] = payment_duration_unit
            __props__.__dict__["payment_type"] = payment_type
            if remark is None and not opts.urn:
                raise TypeError("Missing required property 'remark'")
            __props__.__dict__["remark"] = remark
            __props__.__dict__["resource_group_id"] = resource_group_id
            __props__.__dict__["resource_group_name"] = resource_group_name
            __props__.__dict__["specification"] = specification
            __props__.__dict__["tags"] = tags
            __props__.__dict__["create_time"] = None
            __props__.__dict__["status"] = None
        super(DwResourceGroup, __self__).__init__(
            'alicloud:dataworks/dwResourceGroup:DwResourceGroup',
            resource_name,
            __props__,
            opts)

    @staticmethod
    def get(resource_name: str,
            id: pulumi.Input[str],
            opts: Optional[pulumi.ResourceOptions] = None,
            auto_renew: Optional[pulumi.Input[bool]] = None,
            create_time: Optional[pulumi.Input[int]] = None,
            default_vpc_id: Optional[pulumi.Input[str]] = None,
            default_vswitch_id: Optional[pulumi.Input[str]] = None,
            payment_duration: Optional[pulumi.Input[int]] = None,
            payment_duration_unit: Optional[pulumi.Input[str]] = None,
            payment_type: Optional[pulumi.Input[str]] = None,
            remark: Optional[pulumi.Input[str]] = None,
            resource_group_id: Optional[pulumi.Input[str]] = None,
            resource_group_name: Optional[pulumi.Input[str]] = None,
            specification: Optional[pulumi.Input[int]] = None,
            status: Optional[pulumi.Input[str]] = None,
            tags: Optional[pulumi.Input[Mapping[str, pulumi.Input[str]]]] = None) -> 'DwResourceGroup':
        """
        Get an existing DwResourceGroup resource's state with the given name, id, and optional extra
        properties used to qualify the lookup.

        :param str resource_name: The unique name of the resulting resource.
        :param pulumi.Input[str] id: The unique provider ID of the resource to lookup.
        :param pulumi.ResourceOptions opts: Options for the resource.
        :param pulumi.Input[bool] auto_renew: Whether to automatically renew. The default value is false.
        :param pulumi.Input[int] create_time: Resource group creation time
        :param pulumi.Input[str] default_vpc_id: The VPC ID of the default network resource.
        :param pulumi.Input[str] default_vswitch_id: The ID of the vswitch bound to the network resource by default.
        :param pulumi.Input[int] payment_duration: When the payment method is Prepaid, the unit is PaymentDurationUnit.
        :param pulumi.Input[str] payment_duration_unit: When the payment method is Prepaid, the payment duration unit, Month is Month, Year is Year, and there is no other optional value.
        :param pulumi.Input[str] payment_type: The billing type of the resource group. PrePaid is Subscription, and PostPaid is Pay-As-You-Go.
        :param pulumi.Input[str] remark: Resource Group Comments
        :param pulumi.Input[str] resource_group_id: The ID of the resource group
        :param pulumi.Input[str] resource_group_name: Resource group name
        :param pulumi.Input[int] specification: Package year and package month resource group specifications, unit CU
        :param pulumi.Input[str] status: Resource group status:
        :param pulumi.Input[Mapping[str, pulumi.Input[str]]] tags: The tag of the resource
        """
        opts = pulumi.ResourceOptions.merge(opts, pulumi.ResourceOptions(id=id))

        __props__ = _DwResourceGroupState.__new__(_DwResourceGroupState)

        __props__.__dict__["auto_renew"] = auto_renew
        __props__.__dict__["create_time"] = create_time
        __props__.__dict__["default_vpc_id"] = default_vpc_id
        __props__.__dict__["default_vswitch_id"] = default_vswitch_id
        __props__.__dict__["payment_duration"] = payment_duration
        __props__.__dict__["payment_duration_unit"] = payment_duration_unit
        __props__.__dict__["payment_type"] = payment_type
        __props__.__dict__["remark"] = remark
        __props__.__dict__["resource_group_id"] = resource_group_id
        __props__.__dict__["resource_group_name"] = resource_group_name
        __props__.__dict__["specification"] = specification
        __props__.__dict__["status"] = status
        __props__.__dict__["tags"] = tags
        return DwResourceGroup(resource_name, opts=opts, __props__=__props__)

    @property
    @pulumi.getter(name="autoRenew")
    def auto_renew(self) -> pulumi.Output[Optional[bool]]:
        """
        Whether to automatically renew. The default value is false.
        """
        return pulumi.get(self, "auto_renew")

    @property
    @pulumi.getter(name="createTime")
    def create_time(self) -> pulumi.Output[int]:
        """
        Resource group creation time
        """
        return pulumi.get(self, "create_time")

    @property
    @pulumi.getter(name="defaultVpcId")
    def default_vpc_id(self) -> pulumi.Output[str]:
        """
        The VPC ID of the default network resource.
        """
        return pulumi.get(self, "default_vpc_id")

    @property
    @pulumi.getter(name="defaultVswitchId")
    def default_vswitch_id(self) -> pulumi.Output[str]:
        """
        The ID of the vswitch bound to the network resource by default.
        """
        return pulumi.get(self, "default_vswitch_id")

    @property
    @pulumi.getter(name="paymentDuration")
    def payment_duration(self) -> pulumi.Output[Optional[int]]:
        """
        When the payment method is Prepaid, the unit is PaymentDurationUnit.
        """
        return pulumi.get(self, "payment_duration")

    @property
    @pulumi.getter(name="paymentDurationUnit")
    def payment_duration_unit(self) -> pulumi.Output[Optional[str]]:
        """
        When the payment method is Prepaid, the payment duration unit, Month is Month, Year is Year, and there is no other optional value.
        """
        return pulumi.get(self, "payment_duration_unit")

    @property
    @pulumi.getter(name="paymentType")
    def payment_type(self) -> pulumi.Output[str]:
        """
        The billing type of the resource group. PrePaid is Subscription, and PostPaid is Pay-As-You-Go.
        """
        return pulumi.get(self, "payment_type")

    @property
    @pulumi.getter
    def remark(self) -> pulumi.Output[str]:
        """
        Resource Group Comments
        """
        return pulumi.get(self, "remark")

    @property
    @pulumi.getter(name="resourceGroupId")
    def resource_group_id(self) -> pulumi.Output[str]:
        """
        The ID of the resource group
        """
        return pulumi.get(self, "resource_group_id")

    @property
    @pulumi.getter(name="resourceGroupName")
    def resource_group_name(self) -> pulumi.Output[Optional[str]]:
        """
        Resource group name
        """
        return pulumi.get(self, "resource_group_name")

    @property
    @pulumi.getter
    def specification(self) -> pulumi.Output[Optional[int]]:
        """
        Package year and package month resource group specifications, unit CU
        """
        return pulumi.get(self, "specification")

    @property
    @pulumi.getter
    def status(self) -> pulumi.Output[str]:
        """
        Resource group status:
        """
        return pulumi.get(self, "status")

    @property
    @pulumi.getter
    def tags(self) -> pulumi.Output[Optional[Mapping[str, str]]]:
        """
        The tag of the resource
        """
        return pulumi.get(self, "tags")




# coding=utf-8
# *** WARNING: this file was generated by the Pulumi Terraform Bridge (tfgen) Tool. ***
# *** Do not edit by hand unless you're certain you know what you are doing! ***

import copy
import warnings
import sys
import pulumi
import pulumi.runtime
from typing import Any, Mapping, Optional, Sequence, Union, overload
if sys.version_info >= (3, 11):
    from typing import NotRequired, TypedDict, TypeAlias
else:
    from typing_extensions import NotRequired, TypedDict, TypeAlias
from .. import _utilities
from . import outputs

__all__ = [
    'GetFoldersResult',
    'AwaitableGetFoldersResult',
    'get_folders',
    'get_folders_output',
]

@pulumi.output_type
class GetFoldersResult:
    """
    A collection of values returned by getFolders.
    """
    def __init__(__self__, enable_details=None, folders=None, id=None, ids=None, name_regex=None, names=None, output_file=None, parent_folder_id=None, query_keyword=None):
        if enable_details and not isinstance(enable_details, bool):
            raise TypeError("Expected argument 'enable_details' to be a bool")
        pulumi.set(__self__, "enable_details", enable_details)
        if folders and not isinstance(folders, list):
            raise TypeError("Expected argument 'folders' to be a list")
        pulumi.set(__self__, "folders", folders)
        if id and not isinstance(id, str):
            raise TypeError("Expected argument 'id' to be a str")
        pulumi.set(__self__, "id", id)
        if ids and not isinstance(ids, list):
            raise TypeError("Expected argument 'ids' to be a list")
        pulumi.set(__self__, "ids", ids)
        if name_regex and not isinstance(name_regex, str):
            raise TypeError("Expected argument 'name_regex' to be a str")
        pulumi.set(__self__, "name_regex", name_regex)
        if names and not isinstance(names, list):
            raise TypeError("Expected argument 'names' to be a list")
        pulumi.set(__self__, "names", names)
        if output_file and not isinstance(output_file, str):
            raise TypeError("Expected argument 'output_file' to be a str")
        pulumi.set(__self__, "output_file", output_file)
        if parent_folder_id and not isinstance(parent_folder_id, str):
            raise TypeError("Expected argument 'parent_folder_id' to be a str")
        pulumi.set(__self__, "parent_folder_id", parent_folder_id)
        if query_keyword and not isinstance(query_keyword, str):
            raise TypeError("Expected argument 'query_keyword' to be a str")
        pulumi.set(__self__, "query_keyword", query_keyword)

    @property
    @pulumi.getter(name="enableDetails")
    def enable_details(self) -> Optional[bool]:
        return pulumi.get(self, "enable_details")

    @property
    @pulumi.getter
    def folders(self) -> Sequence['outputs.GetFoldersFolderResult']:
        """
        A list of Folder. Each element contains the following attributes:
        """
        return pulumi.get(self, "folders")

    @property
    @pulumi.getter
    def id(self) -> str:
        """
        The provider-assigned unique ID for this managed resource.
        """
        return pulumi.get(self, "id")

    @property
    @pulumi.getter
    def ids(self) -> Sequence[str]:
        return pulumi.get(self, "ids")

    @property
    @pulumi.getter(name="nameRegex")
    def name_regex(self) -> Optional[str]:
        return pulumi.get(self, "name_regex")

    @property
    @pulumi.getter
    def names(self) -> Sequence[str]:
        """
        A list of Folder names.
        """
        return pulumi.get(self, "names")

    @property
    @pulumi.getter(name="outputFile")
    def output_file(self) -> Optional[str]:
        return pulumi.get(self, "output_file")

    @property
    @pulumi.getter(name="parentFolderId")
    def parent_folder_id(self) -> Optional[str]:
        """
        (Available since v1.114.0) The ID of the parent folder. **Note:** `parent_folder_id` takes effect only if `enable_details` is set to `true`.
        """
        return pulumi.get(self, "parent_folder_id")

    @property
    @pulumi.getter(name="queryKeyword")
    def query_keyword(self) -> Optional[str]:
        return pulumi.get(self, "query_keyword")


class AwaitableGetFoldersResult(GetFoldersResult):
    # pylint: disable=using-constant-test
    def __await__(self):
        if False:
            yield self
        return GetFoldersResult(
            enable_details=self.enable_details,
            folders=self.folders,
            id=self.id,
            ids=self.ids,
            name_regex=self.name_regex,
            names=self.names,
            output_file=self.output_file,
            parent_folder_id=self.parent_folder_id,
            query_keyword=self.query_keyword)


def get_folders(enable_details: Optional[bool] = None,
                ids: Optional[Sequence[str]] = None,
                name_regex: Optional[str] = None,
                output_file: Optional[str] = None,
                parent_folder_id: Optional[str] = None,
                query_keyword: Optional[str] = None,
                opts: Optional[pulumi.InvokeOptions] = None) -> AwaitableGetFoldersResult:
    """
    This data source provides the Resource Manager Folders of the current Alibaba Cloud user.

    > **NOTE:** Available since v1.84.0.

    ## Example Usage

    Basic Usage

    ```python
    import pulumi
    import pulumi_alicloud as alicloud

    config = pulumi.Config()
    name = config.get("name")
    if name is None:
        name = "terraform-example"
    default = alicloud.resourcemanager.Folder("default", folder_name=name)
    ids = alicloud.resourcemanager.get_folders_output(ids=[default.id])
    pulumi.export("resourceManagerFolderId0", ids.folders[0].id)
    ```


    :param bool enable_details: Whether to query the detailed list of resource attributes. Default value: `false`.
    :param Sequence[str] ids: A list of Folders IDs.
    :param str name_regex: A regex string to filter results by Folder name.
    :param str output_file: File name where to save data source results (after running `pulumi preview`).
    :param str parent_folder_id: The ID of the parent folder. **NOTE:** If `parent_folder_id` is not set, the information of the first-level subfolders of the Root folder is queried.
    :param str query_keyword: The keyword used for the query, such as a folder name. Fuzzy match is supported.
    """
    __args__ = dict()
    __args__['enableDetails'] = enable_details
    __args__['ids'] = ids
    __args__['nameRegex'] = name_regex
    __args__['outputFile'] = output_file
    __args__['parentFolderId'] = parent_folder_id
    __args__['queryKeyword'] = query_keyword
    opts = pulumi.InvokeOptions.merge(_utilities.get_invoke_opts_defaults(), opts)
    __ret__ = pulumi.runtime.invoke('alicloud:resourcemanager/getFolders:getFolders', __args__, opts=opts, typ=GetFoldersResult).value

    return AwaitableGetFoldersResult(
        enable_details=pulumi.get(__ret__, 'enable_details'),
        folders=pulumi.get(__ret__, 'folders'),
        id=pulumi.get(__ret__, 'id'),
        ids=pulumi.get(__ret__, 'ids'),
        name_regex=pulumi.get(__ret__, 'name_regex'),
        names=pulumi.get(__ret__, 'names'),
        output_file=pulumi.get(__ret__, 'output_file'),
        parent_folder_id=pulumi.get(__ret__, 'parent_folder_id'),
        query_keyword=pulumi.get(__ret__, 'query_keyword'))
def get_folders_output(enable_details: Optional[pulumi.Input[Optional[bool]]] = None,
                       ids: Optional[pulumi.Input[Optional[Sequence[str]]]] = None,
                       name_regex: Optional[pulumi.Input[Optional[str]]] = None,
                       output_file: Optional[pulumi.Input[Optional[str]]] = None,
                       parent_folder_id: Optional[pulumi.Input[Optional[str]]] = None,
                       query_keyword: Optional[pulumi.Input[Optional[str]]] = None,
                       opts: Optional[Union[pulumi.InvokeOptions, pulumi.InvokeOutputOptions]] = None) -> pulumi.Output[GetFoldersResult]:
    """
    This data source provides the Resource Manager Folders of the current Alibaba Cloud user.

    > **NOTE:** Available since v1.84.0.

    ## Example Usage

    Basic Usage

    ```python
    import pulumi
    import pulumi_alicloud as alicloud

    config = pulumi.Config()
    name = config.get("name")
    if name is None:
        name = "terraform-example"
    default = alicloud.resourcemanager.Folder("default", folder_name=name)
    ids = alicloud.resourcemanager.get_folders_output(ids=[default.id])
    pulumi.export("resourceManagerFolderId0", ids.folders[0].id)
    ```


    :param bool enable_details: Whether to query the detailed list of resource attributes. Default value: `false`.
    :param Sequence[str] ids: A list of Folders IDs.
    :param str name_regex: A regex string to filter results by Folder name.
    :param str output_file: File name where to save data source results (after running `pulumi preview`).
    :param str parent_folder_id: The ID of the parent folder. **NOTE:** If `parent_folder_id` is not set, the information of the first-level subfolders of the Root folder is queried.
    :param str query_keyword: The keyword used for the query, such as a folder name. Fuzzy match is supported.
    """
    __args__ = dict()
    __args__['enableDetails'] = enable_details
    __args__['ids'] = ids
    __args__['nameRegex'] = name_regex
    __args__['outputFile'] = output_file
    __args__['parentFolderId'] = parent_folder_id
    __args__['queryKeyword'] = query_keyword
    opts = pulumi.InvokeOutputOptions.merge(_utilities.get_invoke_opts_defaults(), opts)
    __ret__ = pulumi.runtime.invoke_output('alicloud:resourcemanager/getFolders:getFolders', __args__, opts=opts, typ=GetFoldersResult)
    return __ret__.apply(lambda __response__: GetFoldersResult(
        enable_details=pulumi.get(__response__, 'enable_details'),
        folders=pulumi.get(__response__, 'folders'),
        id=pulumi.get(__response__, 'id'),
        ids=pulumi.get(__response__, 'ids'),
        name_regex=pulumi.get(__response__, 'name_regex'),
        names=pulumi.get(__response__, 'names'),
        output_file=pulumi.get(__response__, 'output_file'),
        parent_folder_id=pulumi.get(__response__, 'parent_folder_id'),
        query_keyword=pulumi.get(__response__, 'query_keyword')))



# coding=utf-8
# *** WARNING: this file was generated by the Pulumi Terraform Bridge (tfgen) Tool. ***
# *** Do not edit by hand unless you're certain you know what you are doing! ***

import copy
import warnings
import sys
import pulumi
import pulumi.runtime
from typing import Any, Mapping, Optional, Sequence, Union, overload
if sys.version_info >= (3, 11):
    from typing import NotRequired, TypedDict, TypeAlias
else:
    from typing_extensions import NotRequired, TypedDict, TypeAlias
from .. import _utilities
from . import outputs
from ._inputs import *

__all__ = ['RecordArgs', 'Record']

@pulumi.input_type
class RecordArgs:
    def __init__(__self__, *,
                 data: pulumi.Input['RecordDataArgs'],
                 record_name: pulumi.Input[str],
                 record_type: pulumi.Input[str],
                 site_id: pulumi.Input[int],
                 auth_conf: Optional[pulumi.Input['RecordAuthConfArgs']] = None,
                 biz_name: Optional[pulumi.Input[str]] = None,
                 comment: Optional[pulumi.Input[str]] = None,
                 host_policy: Optional[pulumi.Input[str]] = None,
                 proxied: Optional[pulumi.Input[bool]] = None,
                 source_type: Optional[pulumi.Input[str]] = None,
                 ttl: Optional[pulumi.Input[int]] = None):
        """
        The set of arguments for constructing a Record resource.
        :param pulumi.Input['RecordDataArgs'] data: The DNS record information. The format of this field varies based on the record type. For more information, see [Add DNS records](https://www.alibabacloud.com/help/doc-detail/2708761.html). See `data` below.
        :param pulumi.Input[str] record_name: The record name. This parameter specifies a filter condition for the query.
        :param pulumi.Input[str] record_type: The DNS record type.
        :param pulumi.Input[int] site_id: The website ID, which can be obtained by calling the [ListSites](https://www.alibabacloud.com/help/en/doc-detail/2850189.html) operation.
        :param pulumi.Input['RecordAuthConfArgs'] auth_conf: The origin authentication information of the CNAME record. See `auth_conf` below.
        :param pulumi.Input[str] biz_name: The business scenario of the record for acceleration. Valid values:
        :param pulumi.Input[str] comment: The comments of the record.
        :param pulumi.Input[str] host_policy: The origin host policy. This policy takes effect when the record type is CNAME. You can set the policy in two modes:
        :param pulumi.Input[bool] proxied: Filters by whether the record is proxied. Valid values:
        :param pulumi.Input[str] source_type: The origin type of the record. Only CNAME records can be filtered by using this field. Valid values:
               
               - `OSS`: OSS bucket.
               - `S3`: S3 bucket.
               - `LB`: load balancer.
               - `OP`: origin pool.
               - `Domain`: domain name.
        :param pulumi.Input[int] ttl: The TTL of the record. Unit: seconds. The range is 30 to 86,400, or 1. If the value is 1, the TTL of the record is determined by the system.
        """
        pulumi.set(__self__, "data", data)
        pulumi.set(__self__, "record_name", record_name)
        pulumi.set(__self__, "record_type", record_type)
        pulumi.set(__self__, "site_id", site_id)
        if auth_conf is not None:
            pulumi.set(__self__, "auth_conf", auth_conf)
        if biz_name is not None:
            pulumi.set(__self__, "biz_name", biz_name)
        if comment is not None:
            pulumi.set(__self__, "comment", comment)
        if host_policy is not None:
            pulumi.set(__self__, "host_policy", host_policy)
        if proxied is not None:
            pulumi.set(__self__, "proxied", proxied)
        if source_type is not None:
            pulumi.set(__self__, "source_type", source_type)
        if ttl is not None:
            pulumi.set(__self__, "ttl", ttl)

    @property
    @pulumi.getter
    def data(self) -> pulumi.Input['RecordDataArgs']:
        """
        The DNS record information. The format of this field varies based on the record type. For more information, see [Add DNS records](https://www.alibabacloud.com/help/doc-detail/2708761.html). See `data` below.
        """
        return pulumi.get(self, "data")

    @data.setter
    def data(self, value: pulumi.Input['RecordDataArgs']):
        pulumi.set(self, "data", value)

    @property
    @pulumi.getter(name="recordName")
    def record_name(self) -> pulumi.Input[str]:
        """
        The record name. This parameter specifies a filter condition for the query.
        """
        return pulumi.get(self, "record_name")

    @record_name.setter
    def record_name(self, value: pulumi.Input[str]):
        pulumi.set(self, "record_name", value)

    @property
    @pulumi.getter(name="recordType")
    def record_type(self) -> pulumi.Input[str]:
        """
        The DNS record type.
        """
        return pulumi.get(self, "record_type")

    @record_type.setter
    def record_type(self, value: pulumi.Input[str]):
        pulumi.set(self, "record_type", value)

    @property
    @pulumi.getter(name="siteId")
    def site_id(self) -> pulumi.Input[int]:
        """
        The website ID, which can be obtained by calling the [ListSites](https://www.alibabacloud.com/help/en/doc-detail/2850189.html) operation.
        """
        return pulumi.get(self, "site_id")

    @site_id.setter
    def site_id(self, value: pulumi.Input[int]):
        pulumi.set(self, "site_id", value)

    @property
    @pulumi.getter(name="authConf")
    def auth_conf(self) -> Optional[pulumi.Input['RecordAuthConfArgs']]:
        """
        The origin authentication information of the CNAME record. See `auth_conf` below.
        """
        return pulumi.get(self, "auth_conf")

    @auth_conf.setter
    def auth_conf(self, value: Optional[pulumi.Input['RecordAuthConfArgs']]):
        pulumi.set(self, "auth_conf", value)

    @property
    @pulumi.getter(name="bizName")
    def biz_name(self) -> Optional[pulumi.Input[str]]:
        """
        The business scenario of the record for acceleration. Valid values:
        """
        return pulumi.get(self, "biz_name")

    @biz_name.setter
    def biz_name(self, value: Optional[pulumi.Input[str]]):
        pulumi.set(self, "biz_name", value)

    @property
    @pulumi.getter
    def comment(self) -> Optional[pulumi.Input[str]]:
        """
        The comments of the record.
        """
        return pulumi.get(self, "comment")

    @comment.setter
    def comment(self, value: Optional[pulumi.Input[str]]):
        pulumi.set(self, "comment", value)

    @property
    @pulumi.getter(name="hostPolicy")
    def host_policy(self) -> Optional[pulumi.Input[str]]:
        """
        The origin host policy. This policy takes effect when the record type is CNAME. You can set the policy in two modes:
        """
        return pulumi.get(self, "host_policy")

    @host_policy.setter
    def host_policy(self, value: Optional[pulumi.Input[str]]):
        pulumi.set(self, "host_policy", value)

    @property
    @pulumi.getter
    def proxied(self) -> Optional[pulumi.Input[bool]]:
        """
        Filters by whether the record is proxied. Valid values:
        """
        return pulumi.get(self, "proxied")

    @proxied.setter
    def proxied(self, value: Optional[pulumi.Input[bool]]):
        pulumi.set(self, "proxied", value)

    @property
    @pulumi.getter(name="sourceType")
    def source_type(self) -> Optional[pulumi.Input[str]]:
        """
        The origin type of the record. Only CNAME records can be filtered by using this field. Valid values:

        - `OSS`: OSS bucket.
        - `S3`: S3 bucket.
        - `LB`: load balancer.
        - `OP`: origin pool.
        - `Domain`: domain name.
        """
        return pulumi.get(self, "source_type")

    @source_type.setter
    def source_type(self, value: Optional[pulumi.Input[str]]):
        pulumi.set(self, "source_type", value)

    @property
    @pulumi.getter
    def ttl(self) -> Optional[pulumi.Input[int]]:
        """
        The TTL of the record. Unit: seconds. The range is 30 to 86,400, or 1. If the value is 1, the TTL of the record is determined by the system.
        """
        return pulumi.get(self, "ttl")

    @ttl.setter
    def ttl(self, value: Optional[pulumi.Input[int]]):
        pulumi.set(self, "ttl", value)


@pulumi.input_type
class _RecordState:
    def __init__(__self__, *,
                 auth_conf: Optional[pulumi.Input['RecordAuthConfArgs']] = None,
                 biz_name: Optional[pulumi.Input[str]] = None,
                 comment: Optional[pulumi.Input[str]] = None,
                 create_time: Optional[pulumi.Input[str]] = None,
                 data: Optional[pulumi.Input['RecordDataArgs']] = None,
                 host_policy: Optional[pulumi.Input[str]] = None,
                 proxied: Optional[pulumi.Input[bool]] = None,
                 record_name: Optional[pulumi.Input[str]] = None,
                 record_type: Optional[pulumi.Input[str]] = None,
                 site_id: Optional[pulumi.Input[int]] = None,
                 source_type: Optional[pulumi.Input[str]] = None,
                 ttl: Optional[pulumi.Input[int]] = None):
        """
        Input properties used for looking up and filtering Record resources.
        :param pulumi.Input['RecordAuthConfArgs'] auth_conf: The origin authentication information of the CNAME record. See `auth_conf` below.
        :param pulumi.Input[str] biz_name: The business scenario of the record for acceleration. Valid values:
        :param pulumi.Input[str] comment: The comments of the record.
        :param pulumi.Input[str] create_time: The creation time of the record. The date format follows ISO8601 notation and uses UTC time. The format is yyyy-MM-ddTHH:mm:ssZ.
        :param pulumi.Input['RecordDataArgs'] data: The DNS record information. The format of this field varies based on the record type. For more information, see [Add DNS records](https://www.alibabacloud.com/help/doc-detail/2708761.html). See `data` below.
        :param pulumi.Input[str] host_policy: The origin host policy. This policy takes effect when the record type is CNAME. You can set the policy in two modes:
        :param pulumi.Input[bool] proxied: Filters by whether the record is proxied. Valid values:
        :param pulumi.Input[str] record_name: The record name. This parameter specifies a filter condition for the query.
        :param pulumi.Input[str] record_type: The DNS record type.
        :param pulumi.Input[int] site_id: The website ID, which can be obtained by calling the [ListSites](https://www.alibabacloud.com/help/en/doc-detail/2850189.html) operation.
        :param pulumi.Input[str] source_type: The origin type of the record. Only CNAME records can be filtered by using this field. Valid values:
               
               - `OSS`: OSS bucket.
               - `S3`: S3 bucket.
               - `LB`: load balancer.
               - `OP`: origin pool.
               - `Domain`: domain name.
        :param pulumi.Input[int] ttl: The TTL of the record. Unit: seconds. The range is 30 to 86,400, or 1. If the value is 1, the TTL of the record is determined by the system.
        """
        if auth_conf is not None:
            pulumi.set(__self__, "auth_conf", auth_conf)
        if biz_name is not None:
            pulumi.set(__self__, "biz_name", biz_name)
        if comment is not None:
            pulumi.set(__self__, "comment", comment)
        if create_time is not None:
            pulumi.set(__self__, "create_time", create_time)
        if data is not None:
            pulumi.set(__self__, "data", data)
        if host_policy is not None:
            pulumi.set(__self__, "host_policy", host_policy)
        if proxied is not None:
            pulumi.set(__self__, "proxied", proxied)
        if record_name is not None:
            pulumi.set(__self__, "record_name", record_name)
        if record_type is not None:
            pulumi.set(__self__, "record_type", record_type)
        if site_id is not None:
            pulumi.set(__self__, "site_id", site_id)
        if source_type is not None:
            pulumi.set(__self__, "source_type", source_type)
        if ttl is not None:
            pulumi.set(__self__, "ttl", ttl)

    @property
    @pulumi.getter(name="authConf")
    def auth_conf(self) -> Optional[pulumi.Input['RecordAuthConfArgs']]:
        """
        The origin authentication information of the CNAME record. See `auth_conf` below.
        """
        return pulumi.get(self, "auth_conf")

    @auth_conf.setter
    def auth_conf(self, value: Optional[pulumi.Input['RecordAuthConfArgs']]):
        pulumi.set(self, "auth_conf", value)

    @property
    @pulumi.getter(name="bizName")
    def biz_name(self) -> Optional[pulumi.Input[str]]:
        """
        The business scenario of the record for acceleration. Valid values:
        """
        return pulumi.get(self, "biz_name")

    @biz_name.setter
    def biz_name(self, value: Optional[pulumi.Input[str]]):
        pulumi.set(self, "biz_name", value)

    @property
    @pulumi.getter
    def comment(self) -> Optional[pulumi.Input[str]]:
        """
        The comments of the record.
        """
        return pulumi.get(self, "comment")

    @comment.setter
    def comment(self, value: Optional[pulumi.Input[str]]):
        pulumi.set(self, "comment", value)

    @property
    @pulumi.getter(name="createTime")
    def create_time(self) -> Optional[pulumi.Input[str]]:
        """
        The creation time of the record. The date format follows ISO8601 notation and uses UTC time. The format is yyyy-MM-ddTHH:mm:ssZ.
        """
        return pulumi.get(self, "create_time")

    @create_time.setter
    def create_time(self, value: Optional[pulumi.Input[str]]):
        pulumi.set(self, "create_time", value)

    @property
    @pulumi.getter
    def data(self) -> Optional[pulumi.Input['RecordDataArgs']]:
        """
        The DNS record information. The format of this field varies based on the record type. For more information, see [Add DNS records](https://www.alibabacloud.com/help/doc-detail/2708761.html). See `data` below.
        """
        return pulumi.get(self, "data")

    @data.setter
    def data(self, value: Optional[pulumi.Input['RecordDataArgs']]):
        pulumi.set(self, "data", value)

    @property
    @pulumi.getter(name="hostPolicy")
    def host_policy(self) -> Optional[pulumi.Input[str]]:
        """
        The origin host policy. This policy takes effect when the record type is CNAME. You can set the policy in two modes:
        """
        return pulumi.get(self, "host_policy")

    @host_policy.setter
    def host_policy(self, value: Optional[pulumi.Input[str]]):
        pulumi.set(self, "host_policy", value)

    @property
    @pulumi.getter
    def proxied(self) -> Optional[pulumi.Input[bool]]:
        """
        Filters by whether the record is proxied. Valid values:
        """
        return pulumi.get(self, "proxied")

    @proxied.setter
    def proxied(self, value: Optional[pulumi.Input[bool]]):
        pulumi.set(self, "proxied", value)

    @property
    @pulumi.getter(name="recordName")
    def record_name(self) -> Optional[pulumi.Input[str]]:
        """
        The record name. This parameter specifies a filter condition for the query.
        """
        return pulumi.get(self, "record_name")

    @record_name.setter
    def record_name(self, value: Optional[pulumi.Input[str]]):
        pulumi.set(self, "record_name", value)

    @property
    @pulumi.getter(name="recordType")
    def record_type(self) -> Optional[pulumi.Input[str]]:
        """
        The DNS record type.
        """
        return pulumi.get(self, "record_type")

    @record_type.setter
    def record_type(self, value: Optional[pulumi.Input[str]]):
        pulumi.set(self, "record_type", value)

    @property
    @pulumi.getter(name="siteId")
    def site_id(self) -> Optional[pulumi.Input[int]]:
        """
        The website ID, which can be obtained by calling the [ListSites](https://www.alibabacloud.com/help/en/doc-detail/2850189.html) operation.
        """
        return pulumi.get(self, "site_id")

    @site_id.setter
    def site_id(self, value: Optional[pulumi.Input[int]]):
        pulumi.set(self, "site_id", value)

    @property
    @pulumi.getter(name="sourceType")
    def source_type(self) -> Optional[pulumi.Input[str]]:
        """
        The origin type of the record. Only CNAME records can be filtered by using this field. Valid values:

        - `OSS`: OSS bucket.
        - `S3`: S3 bucket.
        - `LB`: load balancer.
        - `OP`: origin pool.
        - `Domain`: domain name.
        """
        return pulumi.get(self, "source_type")

    @source_type.setter
    def source_type(self, value: Optional[pulumi.Input[str]]):
        pulumi.set(self, "source_type", value)

    @property
    @pulumi.getter
    def ttl(self) -> Optional[pulumi.Input[int]]:
        """
        The TTL of the record. Unit: seconds. The range is 30 to 86,400, or 1. If the value is 1, the TTL of the record is determined by the system.
        """
        return pulumi.get(self, "ttl")

    @ttl.setter
    def ttl(self, value: Optional[pulumi.Input[int]]):
        pulumi.set(self, "ttl", value)


class Record(pulumi.CustomResource):
    @overload
    def __init__(__self__,
                 resource_name: str,
                 opts: Optional[pulumi.ResourceOptions] = None,
                 auth_conf: Optional[pulumi.Input[Union['RecordAuthConfArgs', 'RecordAuthConfArgsDict']]] = None,
                 biz_name: Optional[pulumi.Input[str]] = None,
                 comment: Optional[pulumi.Input[str]] = None,
                 data: Optional[pulumi.Input[Union['RecordDataArgs', 'RecordDataArgsDict']]] = None,
                 host_policy: Optional[pulumi.Input[str]] = None,
                 proxied: Optional[pulumi.Input[bool]] = None,
                 record_name: Optional[pulumi.Input[str]] = None,
                 record_type: Optional[pulumi.Input[str]] = None,
                 site_id: Optional[pulumi.Input[int]] = None,
                 source_type: Optional[pulumi.Input[str]] = None,
                 ttl: Optional[pulumi.Input[int]] = None,
                 __props__=None):
        """
        Provides a ESA Record resource.

        For information about ESA Record and how to use it, see [What is Record](https://www.alibabacloud.com/help/en/).

        > **NOTE:** Available since v1.240.0.

        ## Example Usage

        Basic Usage

        ```python
        import pulumi
        import pulumi_alicloud as alicloud

        config = pulumi.Config()
        name = config.get("name")
        if name is None:
            name = "terraform-example"
        default = alicloud.esa.RatePlanInstance("default",
            type="NS",
            auto_renew=False,
            period=1,
            payment_type="Subscription",
            coverage="overseas",
            auto_pay=True,
            plan_name="high")
        default_site = alicloud.esa.Site("default",
            site_name="idlexamplerecord.com",
            instance_id=default.id,
            coverage="overseas",
            access_type="NS")
        default_record = alicloud.esa.Record("default",
            data={
                "value": "www.eerrraaa.com",
                "weight": 1,
                "priority": 1,
                "port": 80,
            },
            ttl=100,
            record_name="_udp._sip.idlexamplerecord.com",
            comment="This is a remark",
            site_id=default_site.id,
            record_type="SRV")
        ```

        ## Import

        ESA Record can be imported using the id, e.g.

        ```sh
        $ pulumi import alicloud:esa/record:Record example <id>
        ```

        :param str resource_name: The name of the resource.
        :param pulumi.ResourceOptions opts: Options for the resource.
        :param pulumi.Input[Union['RecordAuthConfArgs', 'RecordAuthConfArgsDict']] auth_conf: The origin authentication information of the CNAME record. See `auth_conf` below.
        :param pulumi.Input[str] biz_name: The business scenario of the record for acceleration. Valid values:
        :param pulumi.Input[str] comment: The comments of the record.
        :param pulumi.Input[Union['RecordDataArgs', 'RecordDataArgsDict']] data: The DNS record information. The format of this field varies based on the record type. For more information, see [Add DNS records](https://www.alibabacloud.com/help/doc-detail/2708761.html). See `data` below.
        :param pulumi.Input[str] host_policy: The origin host policy. This policy takes effect when the record type is CNAME. You can set the policy in two modes:
        :param pulumi.Input[bool] proxied: Filters by whether the record is proxied. Valid values:
        :param pulumi.Input[str] record_name: The record name. This parameter specifies a filter condition for the query.
        :param pulumi.Input[str] record_type: The DNS record type.
        :param pulumi.Input[int] site_id: The website ID, which can be obtained by calling the [ListSites](https://www.alibabacloud.com/help/en/doc-detail/2850189.html) operation.
        :param pulumi.Input[str] source_type: The origin type of the record. Only CNAME records can be filtered by using this field. Valid values:
               
               - `OSS`: OSS bucket.
               - `S3`: S3 bucket.
               - `LB`: load balancer.
               - `OP`: origin pool.
               - `Domain`: domain name.
        :param pulumi.Input[int] ttl: The TTL of the record. Unit: seconds. The range is 30 to 86,400, or 1. If the value is 1, the TTL of the record is determined by the system.
        """
        ...
    @overload
    def __init__(__self__,
                 resource_name: str,
                 args: RecordArgs,
                 opts: Optional[pulumi.ResourceOptions] = None):
        """
        Provides a ESA Record resource.

        For information about ESA Record and how to use it, see [What is Record](https://www.alibabacloud.com/help/en/).

        > **NOTE:** Available since v1.240.0.

        ## Example Usage

        Basic Usage

        ```python
        import pulumi
        import pulumi_alicloud as alicloud

        config = pulumi.Config()
        name = config.get("name")
        if name is None:
            name = "terraform-example"
        default = alicloud.esa.RatePlanInstance("default",
            type="NS",
            auto_renew=False,
            period=1,
            payment_type="Subscription",
            coverage="overseas",
            auto_pay=True,
            plan_name="high")
        default_site = alicloud.esa.Site("default",
            site_name="idlexamplerecord.com",
            instance_id=default.id,
            coverage="overseas",
            access_type="NS")
        default_record = alicloud.esa.Record("default",
            data={
                "value": "www.eerrraaa.com",
                "weight": 1,
                "priority": 1,
                "port": 80,
            },
            ttl=100,
            record_name="_udp._sip.idlexamplerecord.com",
            comment="This is a remark",
            site_id=default_site.id,
            record_type="SRV")
        ```

        ## Import

        ESA Record can be imported using the id, e.g.

        ```sh
        $ pulumi import alicloud:esa/record:Record example <id>
        ```

        :param str resource_name: The name of the resource.
        :param RecordArgs args: The arguments to use to populate this resource's properties.
        :param pulumi.ResourceOptions opts: Options for the resource.
        """
        ...
    def __init__(__self__, resource_name: str, *args, **kwargs):
        resource_args, opts = _utilities.get_resource_args_opts(RecordArgs, pulumi.ResourceOptions, *args, **kwargs)
        if resource_args is not None:
            __self__._internal_init(resource_name, opts, **resource_args.__dict__)
        else:
            __self__._internal_init(resource_name, *args, **kwargs)

    def _internal_init(__self__,
                 resource_name: str,
                 opts: Optional[pulumi.ResourceOptions] = None,
                 auth_conf: Optional[pulumi.Input[Union['RecordAuthConfArgs', 'RecordAuthConfArgsDict']]] = None,
                 biz_name: Optional[pulumi.Input[str]] = None,
                 comment: Optional[pulumi.Input[str]] = None,
                 data: Optional[pulumi.Input[Union['RecordDataArgs', 'RecordDataArgsDict']]] = None,
                 host_policy: Optional[pulumi.Input[str]] = None,
                 proxied: Optional[pulumi.Input[bool]] = None,
                 record_name: Optional[pulumi.Input[str]] = None,
                 record_type: Optional[pulumi.Input[str]] = None,
                 site_id: Optional[pulumi.Input[int]] = None,
                 source_type: Optional[pulumi.Input[str]] = None,
                 ttl: Optional[pulumi.Input[int]] = None,
                 __props__=None):
        opts = pulumi.ResourceOptions.merge(_utilities.get_resource_opts_defaults(), opts)
        if not isinstance(opts, pulumi.ResourceOptions):
            raise TypeError('Expected resource options to be a ResourceOptions instance')
        if opts.id is None:
            if __props__ is not None:
                raise TypeError('__props__ is only valid when passed in combination with a valid opts.id to get an existing resource')
            __props__ = RecordArgs.__new__(RecordArgs)

            __props__.__dict__["auth_conf"] = auth_conf
            __props__.__dict__["biz_name"] = biz_name
            __props__.__dict__["comment"] = comment
            if data is None and not opts.urn:
                raise TypeError("Missing required property 'data'")
            __props__.__dict__["data"] = data
            __props__.__dict__["host_policy"] = host_policy
            __props__.__dict__["proxied"] = proxied
            if record_name is None and not opts.urn:
                raise TypeError("Missing required property 'record_name'")
            __props__.__dict__["record_name"] = record_name
            if record_type is None and not opts.urn:
                raise TypeError("Missing required property 'record_type'")
            __props__.__dict__["record_type"] = record_type
            if site_id is None and not opts.urn:
                raise TypeError("Missing required property 'site_id'")
            __props__.__dict__["site_id"] = site_id
            __props__.__dict__["source_type"] = source_type
            __props__.__dict__["ttl"] = ttl
            __props__.__dict__["create_time"] = None
        super(Record, __self__).__init__(
            'alicloud:esa/record:Record',
            resource_name,
            __props__,
            opts)

    @staticmethod
    def get(resource_name: str,
            id: pulumi.Input[str],
            opts: Optional[pulumi.ResourceOptions] = None,
            auth_conf: Optional[pulumi.Input[Union['RecordAuthConfArgs', 'RecordAuthConfArgsDict']]] = None,
            biz_name: Optional[pulumi.Input[str]] = None,
            comment: Optional[pulumi.Input[str]] = None,
            create_time: Optional[pulumi.Input[str]] = None,
            data: Optional[pulumi.Input[Union['RecordDataArgs', 'RecordDataArgsDict']]] = None,
            host_policy: Optional[pulumi.Input[str]] = None,
            proxied: Optional[pulumi.Input[bool]] = None,
            record_name: Optional[pulumi.Input[str]] = None,
            record_type: Optional[pulumi.Input[str]] = None,
            site_id: Optional[pulumi.Input[int]] = None,
            source_type: Optional[pulumi.Input[str]] = None,
            ttl: Optional[pulumi.Input[int]] = None) -> 'Record':
        """
        Get an existing Record resource's state with the given name, id, and optional extra
        properties used to qualify the lookup.

        :param str resource_name: The unique name of the resulting resource.
        :param pulumi.Input[str] id: The unique provider ID of the resource to lookup.
        :param pulumi.ResourceOptions opts: Options for the resource.
        :param pulumi.Input[Union['RecordAuthConfArgs', 'RecordAuthConfArgsDict']] auth_conf: The origin authentication information of the CNAME record. See `auth_conf` below.
        :param pulumi.Input[str] biz_name: The business scenario of the record for acceleration. Valid values:
        :param pulumi.Input[str] comment: The comments of the record.
        :param pulumi.Input[str] create_time: The creation time of the record. The date format follows ISO8601 notation and uses UTC time. The format is yyyy-MM-ddTHH:mm:ssZ.
        :param pulumi.Input[Union['RecordDataArgs', 'RecordDataArgsDict']] data: The DNS record information. The format of this field varies based on the record type. For more information, see [Add DNS records](https://www.alibabacloud.com/help/doc-detail/2708761.html). See `data` below.
        :param pulumi.Input[str] host_policy: The origin host policy. This policy takes effect when the record type is CNAME. You can set the policy in two modes:
        :param pulumi.Input[bool] proxied: Filters by whether the record is proxied. Valid values:
        :param pulumi.Input[str] record_name: The record name. This parameter specifies a filter condition for the query.
        :param pulumi.Input[str] record_type: The DNS record type.
        :param pulumi.Input[int] site_id: The website ID, which can be obtained by calling the [ListSites](https://www.alibabacloud.com/help/en/doc-detail/2850189.html) operation.
        :param pulumi.Input[str] source_type: The origin type of the record. Only CNAME records can be filtered by using this field. Valid values:
               
               - `OSS`: OSS bucket.
               - `S3`: S3 bucket.
               - `LB`: load balancer.
               - `OP`: origin pool.
               - `Domain`: domain name.
        :param pulumi.Input[int] ttl: The TTL of the record. Unit: seconds. The range is 30 to 86,400, or 1. If the value is 1, the TTL of the record is determined by the system.
        """
        opts = pulumi.ResourceOptions.merge(opts, pulumi.ResourceOptions(id=id))

        __props__ = _RecordState.__new__(_RecordState)

        __props__.__dict__["auth_conf"] = auth_conf
        __props__.__dict__["biz_name"] = biz_name
        __props__.__dict__["comment"] = comment
        __props__.__dict__["create_time"] = create_time
        __props__.__dict__["data"] = data
        __props__.__dict__["host_policy"] = host_policy
        __props__.__dict__["proxied"] = proxied
        __props__.__dict__["record_name"] = record_name
        __props__.__dict__["record_type"] = record_type
        __props__.__dict__["site_id"] = site_id
        __props__.__dict__["source_type"] = source_type
        __props__.__dict__["ttl"] = ttl
        return Record(resource_name, opts=opts, __props__=__props__)

    @property
    @pulumi.getter(name="authConf")
    def auth_conf(self) -> pulumi.Output[Optional['outputs.RecordAuthConf']]:
        """
        The origin authentication information of the CNAME record. See `auth_conf` below.
        """
        return pulumi.get(self, "auth_conf")

    @property
    @pulumi.getter(name="bizName")
    def biz_name(self) -> pulumi.Output[Optional[str]]:
        """
        The business scenario of the record for acceleration. Valid values:
        """
        return pulumi.get(self, "biz_name")

    @property
    @pulumi.getter
    def comment(self) -> pulumi.Output[Optional[str]]:
        """
        The comments of the record.
        """
        return pulumi.get(self, "comment")

    @property
    @pulumi.getter(name="createTime")
    def create_time(self) -> pulumi.Output[str]:
        """
        The creation time of the record. The date format follows ISO8601 notation and uses UTC time. The format is yyyy-MM-ddTHH:mm:ssZ.
        """
        return pulumi.get(self, "create_time")

    @property
    @pulumi.getter
    def data(self) -> pulumi.Output['outputs.RecordData']:
        """
        The DNS record information. The format of this field varies based on the record type. For more information, see [Add DNS records](https://www.alibabacloud.com/help/doc-detail/2708761.html). See `data` below.
        """
        return pulumi.get(self, "data")

    @property
    @pulumi.getter(name="hostPolicy")
    def host_policy(self) -> pulumi.Output[Optional[str]]:
        """
        The origin host policy. This policy takes effect when the record type is CNAME. You can set the policy in two modes:
        """
        return pulumi.get(self, "host_policy")

    @property
    @pulumi.getter
    def proxied(self) -> pulumi.Output[Optional[bool]]:
        """
        Filters by whether the record is proxied. Valid values:
        """
        return pulumi.get(self, "proxied")

    @property
    @pulumi.getter(name="recordName")
    def record_name(self) -> pulumi.Output[str]:
        """
        The record name. This parameter specifies a filter condition for the query.
        """
        return pulumi.get(self, "record_name")

    @property
    @pulumi.getter(name="recordType")
    def record_type(self) -> pulumi.Output[str]:
        """
        The DNS record type.
        """
        return pulumi.get(self, "record_type")

    @property
    @pulumi.getter(name="siteId")
    def site_id(self) -> pulumi.Output[int]:
        """
        The website ID, which can be obtained by calling the [ListSites](https://www.alibabacloud.com/help/en/doc-detail/2850189.html) operation.
        """
        return pulumi.get(self, "site_id")

    @property
    @pulumi.getter(name="sourceType")
    def source_type(self) -> pulumi.Output[Optional[str]]:
        """
        The origin type of the record. Only CNAME records can be filtered by using this field. Valid values:

        - `OSS`: OSS bucket.
        - `S3`: S3 bucket.
        - `LB`: load balancer.
        - `OP`: origin pool.
        - `Domain`: domain name.
        """
        return pulumi.get(self, "source_type")

    @property
    @pulumi.getter
    def ttl(self) -> pulumi.Output[Optional[int]]:
        """
        The TTL of the record. Unit: seconds. The range is 30 to 86,400, or 1. If the value is 1, the TTL of the record is determined by the system.
        """
        return pulumi.get(self, "ttl")




# coding=utf-8
# *** WARNING: this file was generated by the Pulumi Terraform Bridge (tfgen) Tool. ***
# *** Do not edit by hand unless you're certain you know what you are doing! ***

import copy
import warnings
import sys
import pulumi
import pulumi.runtime
from typing import Any, Mapping, Optional, Sequence, Union, overload
if sys.version_info >= (3, 11):
    from typing import NotRequired, TypedDict, TypeAlias
else:
    from typing_extensions import NotRequired, TypedDict, TypeAlias
from .. import _utilities

__all__ = [
    'LoadBalancerZoneMappingArgs',
    'LoadBalancerZoneMappingArgsDict',
    'LoadBalancerZoneMappingLoadBalancerAddressArgs',
    'LoadBalancerZoneMappingLoadBalancerAddressArgsDict',
    'ServerGroupConnectionDrainConfigArgs',
    'ServerGroupConnectionDrainConfigArgsDict',
    'ServerGroupHealthCheckConfigArgs',
    'ServerGroupHealthCheckConfigArgsDict',
    'ServerGroupServerArgs',
    'ServerGroupServerArgsDict',
]

MYPY = False

if not MYPY:
    class LoadBalancerZoneMappingArgsDict(TypedDict):
        vswitch_id: pulumi.Input[str]
        """
        The ID of the vSwitch in the zone. You can specify only one vSwitch (subnet) in each zone of a GWLB instance.
        """
        zone_id: pulumi.Input[str]
        """
        The zone ID. You can call the DescribeZones operation to query the most recent zone list.
        """
        load_balancer_addresses: NotRequired[pulumi.Input[Sequence[pulumi.Input['LoadBalancerZoneMappingLoadBalancerAddressArgsDict']]]]
        """
        The information about the IP addresses used by the GWLB instance.
        """
elif False:
    LoadBalancerZoneMappingArgsDict: TypeAlias = Mapping[str, Any]

@pulumi.input_type
class LoadBalancerZoneMappingArgs:
    def __init__(__self__, *,
                 vswitch_id: pulumi.Input[str],
                 zone_id: pulumi.Input[str],
                 load_balancer_addresses: Optional[pulumi.Input[Sequence[pulumi.Input['LoadBalancerZoneMappingLoadBalancerAddressArgs']]]] = None):
        """
        :param pulumi.Input[str] vswitch_id: The ID of the vSwitch in the zone. You can specify only one vSwitch (subnet) in each zone of a GWLB instance.
        :param pulumi.Input[str] zone_id: The zone ID. You can call the DescribeZones operation to query the most recent zone list.
        :param pulumi.Input[Sequence[pulumi.Input['LoadBalancerZoneMappingLoadBalancerAddressArgs']]] load_balancer_addresses: The information about the IP addresses used by the GWLB instance.
        """
        pulumi.set(__self__, "vswitch_id", vswitch_id)
        pulumi.set(__self__, "zone_id", zone_id)
        if load_balancer_addresses is not None:
            pulumi.set(__self__, "load_balancer_addresses", load_balancer_addresses)

    @property
    @pulumi.getter(name="vswitchId")
    def vswitch_id(self) -> pulumi.Input[str]:
        """
        The ID of the vSwitch in the zone. You can specify only one vSwitch (subnet) in each zone of a GWLB instance.
        """
        return pulumi.get(self, "vswitch_id")

    @vswitch_id.setter
    def vswitch_id(self, value: pulumi.Input[str]):
        pulumi.set(self, "vswitch_id", value)

    @property
    @pulumi.getter(name="zoneId")
    def zone_id(self) -> pulumi.Input[str]:
        """
        The zone ID. You can call the DescribeZones operation to query the most recent zone list.
        """
        return pulumi.get(self, "zone_id")

    @zone_id.setter
    def zone_id(self, value: pulumi.Input[str]):
        pulumi.set(self, "zone_id", value)

    @property
    @pulumi.getter(name="loadBalancerAddresses")
    def load_balancer_addresses(self) -> Optional[pulumi.Input[Sequence[pulumi.Input['LoadBalancerZoneMappingLoadBalancerAddressArgs']]]]:
        """
        The information about the IP addresses used by the GWLB instance.
        """
        return pulumi.get(self, "load_balancer_addresses")

    @load_balancer_addresses.setter
    def load_balancer_addresses(self, value: Optional[pulumi.Input[Sequence[pulumi.Input['LoadBalancerZoneMappingLoadBalancerAddressArgs']]]]):
        pulumi.set(self, "load_balancer_addresses", value)


if not MYPY:
    class LoadBalancerZoneMappingLoadBalancerAddressArgsDict(TypedDict):
        eni_id: NotRequired[pulumi.Input[str]]
        """
        The ID of the elastic network interface (ENI) used by the GWLB instance.
        """
        private_ipv4_address: NotRequired[pulumi.Input[str]]
        """
        The private IPv4 address.
        """
elif False:
    LoadBalancerZoneMappingLoadBalancerAddressArgsDict: TypeAlias = Mapping[str, Any]

@pulumi.input_type
class LoadBalancerZoneMappingLoadBalancerAddressArgs:
    def __init__(__self__, *,
                 eni_id: Optional[pulumi.Input[str]] = None,
                 private_ipv4_address: Optional[pulumi.Input[str]] = None):
        """
        :param pulumi.Input[str] eni_id: The ID of the elastic network interface (ENI) used by the GWLB instance.
        :param pulumi.Input[str] private_ipv4_address: The private IPv4 address.
        """
        if eni_id is not None:
            pulumi.set(__self__, "eni_id", eni_id)
        if private_ipv4_address is not None:
            pulumi.set(__self__, "private_ipv4_address", private_ipv4_address)

    @property
    @pulumi.getter(name="eniId")
    def eni_id(self) -> Optional[pulumi.Input[str]]:
        """
        The ID of the elastic network interface (ENI) used by the GWLB instance.
        """
        return pulumi.get(self, "eni_id")

    @eni_id.setter
    def eni_id(self, value: Optional[pulumi.Input[str]]):
        pulumi.set(self, "eni_id", value)

    @property
    @pulumi.getter(name="privateIpv4Address")
    def private_ipv4_address(self) -> Optional[pulumi.Input[str]]:
        """
        The private IPv4 address.
        """
        return pulumi.get(self, "private_ipv4_address")

    @private_ipv4_address.setter
    def private_ipv4_address(self, value: Optional[pulumi.Input[str]]):
        pulumi.set(self, "private_ipv4_address", value)


if not MYPY:
    class ServerGroupConnectionDrainConfigArgsDict(TypedDict):
        connection_drain_enabled: NotRequired[pulumi.Input[bool]]
        """
        Indicates whether connection draining is enabled. Valid values:
        """
        connection_drain_timeout: NotRequired[pulumi.Input[int]]
        """
        The timeout period of connection draining.

        Unit: seconds

        Valid values: `1` to `3600`.

        Default value: `300`.
        """
elif False:
    ServerGroupConnectionDrainConfigArgsDict: TypeAlias = Mapping[str, Any]

@pulumi.input_type
class ServerGroupConnectionDrainConfigArgs:
    def __init__(__self__, *,
                 connection_drain_enabled: Optional[pulumi.Input[bool]] = None,
                 connection_drain_timeout: Optional[pulumi.Input[int]] = None):
        """
        :param pulumi.Input[bool] connection_drain_enabled: Indicates whether connection draining is enabled. Valid values:
        :param pulumi.Input[int] connection_drain_timeout: The timeout period of connection draining.
               
               Unit: seconds
               
               Valid values: `1` to `3600`.
               
               Default value: `300`.
        """
        if connection_drain_enabled is not None:
            pulumi.set(__self__, "connection_drain_enabled", connection_drain_enabled)
        if connection_drain_timeout is not None:
            pulumi.set(__self__, "connection_drain_timeout", connection_drain_timeout)

    @property
    @pulumi.getter(name="connectionDrainEnabled")
    def connection_drain_enabled(self) -> Optional[pulumi.Input[bool]]:
        """
        Indicates whether connection draining is enabled. Valid values:
        """
        return pulumi.get(self, "connection_drain_enabled")

    @connection_drain_enabled.setter
    def connection_drain_enabled(self, value: Optional[pulumi.Input[bool]]):
        pulumi.set(self, "connection_drain_enabled", value)

    @property
    @pulumi.getter(name="connectionDrainTimeout")
    def connection_drain_timeout(self) -> Optional[pulumi.Input[int]]:
        """
        The timeout period of connection draining.

        Unit: seconds

        Valid values: `1` to `3600`.

        Default value: `300`.
        """
        return pulumi.get(self, "connection_drain_timeout")

    @connection_drain_timeout.setter
    def connection_drain_timeout(self, value: Optional[pulumi.Input[int]]):
        pulumi.set(self, "connection_drain_timeout", value)


if not MYPY:
    class ServerGroupHealthCheckConfigArgsDict(TypedDict):
        health_check_connect_port: NotRequired[pulumi.Input[int]]
        """
        The backend server port that is used for health checks.

        Valid values: `1` to `65535`.

        Default value: `80`.
        """
        health_check_connect_timeout: NotRequired[pulumi.Input[int]]
        """
        The maximum timeout period of a health check response.

        Unit: seconds

        Valid values: `1` to `300`.

        Default value: `5`.
        """
        health_check_domain: NotRequired[pulumi.Input[str]]
        """
        The domain name that you want to use for health checks. Valid values:

        *   **$SERVER_IP** (default): the private IP address of a backend server.
        """
        health_check_enabled: NotRequired[pulumi.Input[bool]]
        """
        Specifies whether to enable the health check feature. Valid values:
        """
        health_check_http_codes: NotRequired[pulumi.Input[Sequence[pulumi.Input[str]]]]
        """
        The HTTP status codes that the system returns for health checks.
        """
        health_check_interval: NotRequired[pulumi.Input[int]]
        """
        The interval at which health checks are performed.

        Unit: seconds

        Valid values: `1` to `50`.

        Default value: `10`.
        """
        health_check_path: NotRequired[pulumi.Input[str]]
        """
        The URL that is used for health checks.

        The URL must be 1 to 80 characters in length, and can contain letters, digits, hyphens (-), forward slashes (/), periods (.), percent signs (%), question marks (?), number signs (#), and ampersands (&). The URL can also contain the following extended characters: \\_ ; ~ ! ( ) \\* \\[ ] @ $ ^ : ' , + =

        The URL must start with a forward slash (/).

        > **NOTE:**  This parameter takes effect only if you set `HealthCheckProtocol` to `HTTP`.
        """
        health_check_protocol: NotRequired[pulumi.Input[str]]
        """
        The protocol that is used for health checks. Valid values:

        - `TCP`: TCP health checks send TCP SYN packets to a backend server to check whether the port of the backend server is reachable.
        - `HTTP`: HTTP health checks simulate a process that uses a web browser to access resources by sending HEAD or GET requests to an instance. These requests are used to check whether the instance is healthy.
        """
        healthy_threshold: NotRequired[pulumi.Input[int]]
        """
        The number of times that an unhealthy backend server must consecutively pass health checks before it is declared healthy. In this case, the health status changes from `fail` to `success`.

        Valid values: `2` to `10`.

        Default value: `2`.
        """
        unhealthy_threshold: NotRequired[pulumi.Input[int]]
        """
        The number of times that a healthy backend server must consecutively fail health checks before it is declared unhealthy. In this case, the health status changes from `success` to `fail`.

        Valid values: `2` to `10`.

        Default value: `2`.
        """
elif False:
    ServerGroupHealthCheckConfigArgsDict: TypeAlias = Mapping[str, Any]

@pulumi.input_type
class ServerGroupHealthCheckConfigArgs:
    def __init__(__self__, *,
                 health_check_connect_port: Optional[pulumi.Input[int]] = None,
                 health_check_connect_timeout: Optional[pulumi.Input[int]] = None,
                 health_check_domain: Optional[pulumi.Input[str]] = None,
                 health_check_enabled: Optional[pulumi.Input[bool]] = None,
                 health_check_http_codes: Optional[pulumi.Input[Sequence[pulumi.Input[str]]]] = None,
                 health_check_interval: Optional[pulumi.Input[int]] = None,
                 health_check_path: Optional[pulumi.Input[str]] = None,
                 health_check_protocol: Optional[pulumi.Input[str]] = None,
                 healthy_threshold: Optional[pulumi.Input[int]] = None,
                 unhealthy_threshold: Optional[pulumi.Input[int]] = None):
        """
        :param pulumi.Input[int] health_check_connect_port: The backend server port that is used for health checks.
               
               Valid values: `1` to `65535`.
               
               Default value: `80`.
        :param pulumi.Input[int] health_check_connect_timeout: The maximum timeout period of a health check response.
               
               Unit: seconds
               
               Valid values: `1` to `300`.
               
               Default value: `5`.
        :param pulumi.Input[str] health_check_domain: The domain name that you want to use for health checks. Valid values:
               
               *   **$SERVER_IP** (default): the private IP address of a backend server.
        :param pulumi.Input[bool] health_check_enabled: Specifies whether to enable the health check feature. Valid values:
        :param pulumi.Input[Sequence[pulumi.Input[str]]] health_check_http_codes: The HTTP status codes that the system returns for health checks.
        :param pulumi.Input[int] health_check_interval: The interval at which health checks are performed.
               
               Unit: seconds
               
               Valid values: `1` to `50`.
               
               Default value: `10`.
        :param pulumi.Input[str] health_check_path: The URL that is used for health checks.
               
               The URL must be 1 to 80 characters in length, and can contain letters, digits, hyphens (-), forward slashes (/), periods (.), percent signs (%), question marks (?), number signs (#), and ampersands (&). The URL can also contain the following extended characters: \\_ ; ~ ! ( ) \\* \\[ ] @ $ ^ : ' , + =
               
               The URL must start with a forward slash (/).
               
               > **NOTE:**  This parameter takes effect only if you set `HealthCheckProtocol` to `HTTP`.
        :param pulumi.Input[str] health_check_protocol: The protocol that is used for health checks. Valid values:
               
               - `TCP`: TCP health checks send TCP SYN packets to a backend server to check whether the port of the backend server is reachable.
               - `HTTP`: HTTP health checks simulate a process that uses a web browser to access resources by sending HEAD or GET requests to an instance. These requests are used to check whether the instance is healthy.
        :param pulumi.Input[int] healthy_threshold: The number of times that an unhealthy backend server must consecutively pass health checks before it is declared healthy. In this case, the health status changes from `fail` to `success`.
               
               Valid values: `2` to `10`.
               
               Default value: `2`.
        :param pulumi.Input[int] unhealthy_threshold: The number of times that a healthy backend server must consecutively fail health checks before it is declared unhealthy. In this case, the health status changes from `success` to `fail`.
               
               Valid values: `2` to `10`.
               
               Default value: `2`.
        """
        if health_check_connect_port is not None:
            pulumi.set(__self__, "health_check_connect_port", health_check_connect_port)
        if health_check_connect_timeout is not None:
            pulumi.set(__self__, "health_check_connect_timeout", health_check_connect_timeout)
        if health_check_domain is not None:
            pulumi.set(__self__, "health_check_domain", health_check_domain)
        if health_check_enabled is not None:
            pulumi.set(__self__, "health_check_enabled", health_check_enabled)
        if health_check_http_codes is not None:
            pulumi.set(__self__, "health_check_http_codes", health_check_http_codes)
        if health_check_interval is not None:
            pulumi.set(__self__, "health_check_interval", health_check_interval)
        if health_check_path is not None:
            pulumi.set(__self__, "health_check_path", health_check_path)
        if health_check_protocol is not None:
            pulumi.set(__self__, "health_check_protocol", health_check_protocol)
        if healthy_threshold is not None:
            pulumi.set(__self__, "healthy_threshold", healthy_threshold)
        if unhealthy_threshold is not None:
            pulumi.set(__self__, "unhealthy_threshold", unhealthy_threshold)

    @property
    @pulumi.getter(name="healthCheckConnectPort")
    def health_check_connect_port(self) -> Optional[pulumi.Input[int]]:
        """
        The backend server port that is used for health checks.

        Valid values: `1` to `65535`.

        Default value: `80`.
        """
        return pulumi.get(self, "health_check_connect_port")

    @health_check_connect_port.setter
    def health_check_connect_port(self, value: Optional[pulumi.Input[int]]):
        pulumi.set(self, "health_check_connect_port", value)

    @property
    @pulumi.getter(name="healthCheckConnectTimeout")
    def health_check_connect_timeout(self) -> Optional[pulumi.Input[int]]:
        """
        The maximum timeout period of a health check response.

        Unit: seconds

        Valid values: `1` to `300`.

        Default value: `5`.
        """
        return pulumi.get(self, "health_check_connect_timeout")

    @health_check_connect_timeout.setter
    def health_check_connect_timeout(self, value: Optional[pulumi.Input[int]]):
        pulumi.set(self, "health_check_connect_timeout", value)

    @property
    @pulumi.getter(name="healthCheckDomain")
    def health_check_domain(self) -> Optional[pulumi.Input[str]]:
        """
        The domain name that you want to use for health checks. Valid values:

        *   **$SERVER_IP** (default): the private IP address of a backend server.
        """
        return pulumi.get(self, "health_check_domain")

    @health_check_domain.setter
    def health_check_domain(self, value: Optional[pulumi.Input[str]]):
        pulumi.set(self, "health_check_domain", value)

    @property
    @pulumi.getter(name="healthCheckEnabled")
    def health_check_enabled(self) -> Optional[pulumi.Input[bool]]:
        """
        Specifies whether to enable the health check feature. Valid values:
        """
        return pulumi.get(self, "health_check_enabled")

    @health_check_enabled.setter
    def health_check_enabled(self, value: Optional[pulumi.Input[bool]]):
        pulumi.set(self, "health_check_enabled", value)

    @property
    @pulumi.getter(name="healthCheckHttpCodes")
    def health_check_http_codes(self) -> Optional[pulumi.Input[Sequence[pulumi.Input[str]]]]:
        """
        The HTTP status codes that the system returns for health checks.
        """
        return pulumi.get(self, "health_check_http_codes")

    @health_check_http_codes.setter
    def health_check_http_codes(self, value: Optional[pulumi.Input[Sequence[pulumi.Input[str]]]]):
        pulumi.set(self, "health_check_http_codes", value)

    @property
    @pulumi.getter(name="healthCheckInterval")
    def health_check_interval(self) -> Optional[pulumi.Input[int]]:
        """
        The interval at which health checks are performed.

        Unit: seconds

        Valid values: `1` to `50`.

        Default value: `10`.
        """
        return pulumi.get(self, "health_check_interval")

    @health_check_interval.setter
    def health_check_interval(self, value: Optional[pulumi.Input[int]]):
        pulumi.set(self, "health_check_interval", value)

    @property
    @pulumi.getter(name="healthCheckPath")
    def health_check_path(self) -> Optional[pulumi.Input[str]]:
        """
        The URL that is used for health checks.

        The URL must be 1 to 80 characters in length, and can contain letters, digits, hyphens (-), forward slashes (/), periods (.), percent signs (%), question marks (?), number signs (#), and ampersands (&). The URL can also contain the following extended characters: \\_ ; ~ ! ( ) \\* \\[ ] @ $ ^ : ' , + =

        The URL must start with a forward slash (/).

        > **NOTE:**  This parameter takes effect only if you set `HealthCheckProtocol` to `HTTP`.
        """
        return pulumi.get(self, "health_check_path")

    @health_check_path.setter
    def health_check_path(self, value: Optional[pulumi.Input[str]]):
        pulumi.set(self, "health_check_path", value)

    @property
    @pulumi.getter(name="healthCheckProtocol")
    def health_check_protocol(self) -> Optional[pulumi.Input[str]]:
        """
        The protocol that is used for health checks. Valid values:

        - `TCP`: TCP health checks send TCP SYN packets to a backend server to check whether the port of the backend server is reachable.
        - `HTTP`: HTTP health checks simulate a process that uses a web browser to access resources by sending HEAD or GET requests to an instance. These requests are used to check whether the instance is healthy.
        """
        return pulumi.get(self, "health_check_protocol")

    @health_check_protocol.setter
    def health_check_protocol(self, value: Optional[pulumi.Input[str]]):
        pulumi.set(self, "health_check_protocol", value)

    @property
    @pulumi.getter(name="healthyThreshold")
    def healthy_threshold(self) -> Optional[pulumi.Input[int]]:
        """
        The number of times that an unhealthy backend server must consecutively pass health checks before it is declared healthy. In this case, the health status changes from `fail` to `success`.

        Valid values: `2` to `10`.

        Default value: `2`.
        """
        return pulumi.get(self, "healthy_threshold")

    @healthy_threshold.setter
    def healthy_threshold(self, value: Optional[pulumi.Input[int]]):
        pulumi.set(self, "healthy_threshold", value)

    @property
    @pulumi.getter(name="unhealthyThreshold")
    def unhealthy_threshold(self) -> Optional[pulumi.Input[int]]:
        """
        The number of times that a healthy backend server must consecutively fail health checks before it is declared unhealthy. In this case, the health status changes from `success` to `fail`.

        Valid values: `2` to `10`.

        Default value: `2`.
        """
        return pulumi.get(self, "unhealthy_threshold")

    @unhealthy_threshold.setter
    def unhealthy_threshold(self, value: Optional[pulumi.Input[int]]):
        pulumi.set(self, "unhealthy_threshold", value)


if not MYPY:
    class ServerGroupServerArgsDict(TypedDict):
        server_id: pulumi.Input[str]
        """
        The backend server ID.

        - If the server group is of the `Instance` type, set this parameter to the IDs of servers of the `Ecs`, `Eni`, or `Eci` type.
        - If the server group is of the `Ip` type, set ServerId to IP addresses.
        """
        server_type: pulumi.Input[str]
        """
        The type of the backend server. Valid values:

        - `Ecs`: Elastic Compute Service (ECS) instance
        - `Eni`: elastic network interface (ENI)
        - `Eci`: elastic container instance
        - `Ip`: IP address
        """
        port: NotRequired[pulumi.Input[int]]
        """
        (Optional, Computed, Int) The port that is used by the backend server.
        """
        server_group_id: NotRequired[pulumi.Input[str]]
        """
        The server group ID.
        """
        server_ip: NotRequired[pulumi.Input[str]]
        """
        The IP address of the backend server.
        """
        status: NotRequired[pulumi.Input[str]]
        """
        Indicates the status of the backend server.
        """
elif False:
    ServerGroupServerArgsDict: TypeAlias = Mapping[str, Any]

@pulumi.input_type
class ServerGroupServerArgs:
    def __init__(__self__, *,
                 server_id: pulumi.Input[str],
                 server_type: pulumi.Input[str],
                 port: Optional[pulumi.Input[int]] = None,
                 server_group_id: Optional[pulumi.Input[str]] = None,
                 server_ip: Optional[pulumi.Input[str]] = None,
                 status: Optional[pulumi.Input[str]] = None):
        """
        :param pulumi.Input[str] server_id: The backend server ID.
               
               - If the server group is of the `Instance` type, set this parameter to the IDs of servers of the `Ecs`, `Eni`, or `Eci` type.
               - If the server group is of the `Ip` type, set ServerId to IP addresses.
        :param pulumi.Input[str] server_type: The type of the backend server. Valid values:
               
               - `Ecs`: Elastic Compute Service (ECS) instance
               - `Eni`: elastic network interface (ENI)
               - `Eci`: elastic container instance
               - `Ip`: IP address
        :param pulumi.Input[int] port: (Optional, Computed, Int) The port that is used by the backend server.
        :param pulumi.Input[str] server_group_id: The server group ID.
        :param pulumi.Input[str] server_ip: The IP address of the backend server.
        :param pulumi.Input[str] status: Indicates the status of the backend server.
        """
        pulumi.set(__self__, "server_id", server_id)
        pulumi.set(__self__, "server_type", server_type)
        if port is not None:
            pulumi.set(__self__, "port", port)
        if server_group_id is not None:
            pulumi.set(__self__, "server_group_id", server_group_id)
        if server_ip is not None:
            pulumi.set(__self__, "server_ip", server_ip)
        if status is not None:
            pulumi.set(__self__, "status", status)

    @property
    @pulumi.getter(name="serverId")
    def server_id(self) -> pulumi.Input[str]:
        """
        The backend server ID.

        - If the server group is of the `Instance` type, set this parameter to the IDs of servers of the `Ecs`, `Eni`, or `Eci` type.
        - If the server group is of the `Ip` type, set ServerId to IP addresses.
        """
        return pulumi.get(self, "server_id")

    @server_id.setter
    def server_id(self, value: pulumi.Input[str]):
        pulumi.set(self, "server_id", value)

    @property
    @pulumi.getter(name="serverType")
    def server_type(self) -> pulumi.Input[str]:
        """
        The type of the backend server. Valid values:

        - `Ecs`: Elastic Compute Service (ECS) instance
        - `Eni`: elastic network interface (ENI)
        - `Eci`: elastic container instance
        - `Ip`: IP address
        """
        return pulumi.get(self, "server_type")

    @server_type.setter
    def server_type(self, value: pulumi.Input[str]):
        pulumi.set(self, "server_type", value)

    @property
    @pulumi.getter
    def port(self) -> Optional[pulumi.Input[int]]:
        """
        (Optional, Computed, Int) The port that is used by the backend server.
        """
        return pulumi.get(self, "port")

    @port.setter
    def port(self, value: Optional[pulumi.Input[int]]):
        pulumi.set(self, "port", value)

    @property
    @pulumi.getter(name="serverGroupId")
    def server_group_id(self) -> Optional[pulumi.Input[str]]:
        """
        The server group ID.
        """
        return pulumi.get(self, "server_group_id")

    @server_group_id.setter
    def server_group_id(self, value: Optional[pulumi.Input[str]]):
        pulumi.set(self, "server_group_id", value)

    @property
    @pulumi.getter(name="serverIp")
    def server_ip(self) -> Optional[pulumi.Input[str]]:
        """
        The IP address of the backend server.
        """
        return pulumi.get(self, "server_ip")

    @server_ip.setter
    def server_ip(self, value: Optional[pulumi.Input[str]]):
        pulumi.set(self, "server_ip", value)

    @property
    @pulumi.getter
    def status(self) -> Optional[pulumi.Input[str]]:
        """
        Indicates the status of the backend server.
        """
        return pulumi.get(self, "status")

    @status.setter
    def status(self, value: Optional[pulumi.Input[str]]):
        pulumi.set(self, "status", value)


